@@ -2,7 +2,7 @@
  *
  * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright (C) 2009--2020 Filippo Rusconi
+ * Copyright (C) 2009--2024 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
@@ -62,6 +62,7 @@
 #include <libmass/globals.hpp>
 #include <libmass/PeakCentroid.hpp>
 #include "IsotopicData.hpp"
+#include "IsotopicDataUserConfigHandler.hpp"
 
 
 namespace msxps
@@ -302,7 +303,7 @@ IsotopicData::updateAvgMassMap(const QString &symbol)
 
 #if 0
 
-  // Now this is in a function per se: 
+  // Now this is in a function per se:
   // computeAvgMass(IsotopeCstIteratorPair iter_pair, bool *ok)
 
   double cumulated_probabilities = 0.0;
@@ -1134,6 +1135,46 @@ IsotopicData::clear()
   m_symbolAvgMassMap.clear();
 }
 
+
+IsotopicDataSPtr
+loadIsotopicDataFromFile(const QString &file_name, QString &error)
+{
+  qDebug();
+
+  IsotopicDataSPtr isotopic_data_sp = std::make_shared<IsotopicData>();
+
+  if(file_name.isEmpty())
+    {
+      error = "Failed to set the file name.";
+      return nullptr;
+    }
+
+  QFile file(file_name);
+
+  if(!file.open(QIODevice::ReadOnly | QIODevice::Text))
+    {
+      error = "Failed to open the file for reading.";
+      return nullptr;
+    }
+
+  IsotopicDataUserConfigHandler isotopic_data_handler(isotopic_data_sp);
+
+  if(!isotopic_data_handler.loadData(file_name))
+    {
+      error = "Failed to load the isotopic data.";
+      file.close();
+
+      return nullptr;
+    }
+
+  qDebug() << "Loaded isotopic data from file" << file_name;
+
+  file.close();
+
+  return isotopic_data_sp;
+}
+
+
 } // namespace libmass
 
 } // namespace msxps
