@@ -81,7 +81,7 @@ AboutDlg::AboutDlg(QWidget *parent, const QString &applicationName)
   makeUserManualCommandLinkConnections();
 
   m_ui.copyrightLabel->setText(
-    "msXpertSuite Copyright 2016-2021 by Filippo Rusconi");
+    "msXpertSuite Copyright 2016-2024 by Filippo Rusconi");
   m_ui.gplTextEdit->setText(gpl);
 
   setApplicationFeaturesText();
@@ -132,119 +132,47 @@ AboutDlg::setApplicationFeaturesText()
 
 
 void
-AboutDlg::makeUserManualCommandLinkConnections()
-{
-  connect(m_ui.localPdfCommandLinkButton, &QPushButton::clicked, []() {
+  AboutDlg::makeUserManualCommandLinkConnections()
+  {
+    connect(m_ui.localPdfCommandLinkButton, &QPushButton::clicked, []() {
 #include <QDesktopServices>
 #include <QUrl>
-    QString url = "file:///";
-    if(QOperatingSystemVersion::currentType() == QOperatingSystemVersion::MacOS)
-      {
-        // We ship the program as a macOS bundle, so we need to provide
-        // the doc directory inside it.
+      QString url = "file:///";
+      url += DOC_DIR;
+      url += "/minexpert2-doc.pdf";
 
-        url = QCoreApplication::applicationDirPath();
-        url += "/../doc/minexpert2-doc.pdf";
+      // qDebug() << "Opening url:" << url;
 
-        // Use this expedient to remove the /../ path redirection.
-        QFileInfo file_info(url);
-        // Re-seed the url with the proper scheme.
-        url = "file:///";
-        url += file_info.canonicalFilePath();
-      }
-    else
-      {
-        // We may be executing under the AppImage bundle structure. In this
-        // case, we need to provide the full directory path to the documentation
-        // that is not more /usr/share/... as in system GNU/Linux. The root
-        // directory of the AppImage bundle is stored in the APPDIR environment
-        // variable.
+      QDesktopServices::openUrl(QUrl(url));
+    });
 
-        QString app_image_dir = qgetenv("APPDIR");
-
-        if(app_image_dir.isEmpty())
-          {
-            url += DOC_DIR;
-          }
-        else
-          {
-            url += app_image_dir;
-            url += DOC_DIR;
-          }
-
-        // Finally construct the remainder.
-        qInfo() << "Opening url:" << url;
-        url += "/minexpert2-doc.pdf";
-      }
-
-    qInfo() << "Opening url:" << url;
-
-    QDesktopServices::openUrl(QUrl(url));
-  });
-
-  connect(m_ui.wwwPdfCommandLinkButton, &QPushButton::clicked, []() {
+    connect(m_ui.wwwPdfCommandLinkButton, &QPushButton::clicked, []() {
 #include <QDesktopServices>
 #include <QUrl>
-    QDesktopServices::openUrl(
-      QUrl("http://msxpertsuite.org/user-manuals/pdf/minexpert2-doc.pdf"));
-  });
+      QDesktopServices::openUrl(
+        QUrl("http://www.msxpertsuite.org/user-manuals/minexpert2/minexpert2-doc.pdf"));
+    });
 
-  connect(m_ui.localHtmlCommandLinkButton, &QPushButton::clicked, []() {
+    connect(m_ui.localHtmlCommandLinkButton, &QPushButton::clicked, []() {
 #include <QDesktopServices>
 #include <QUrl>
-    QString url = "file:///";
-    if(QOperatingSystemVersion::currentType() == QOperatingSystemVersion::MacOS)
-      {
-        // We ship the program as a macOS bundle, so we need to provide
-        // the doc directory inside it.
-        url = QCoreApplication::applicationDirPath();
-        url += "/../doc/html/index.html";
+      QString url = "file:///";
+      url += DOC_DIR;
+      url += "/html/index.html";
 
-        // Use this expedient to remove the /../ path redirection.
-        QFileInfo file_info(url);
-        // Re-seed the url with the proper scheme.
-        url = "file:///";
-        url += file_info.canonicalFilePath();
-      }
-    else
-      {
-        // We may be executing under the AppImage bundle structure. In this
-        // case, we need to provide the full directory path to the documentation
-        // that is not more /usr/share/... as in system GNU/Linux. The root
-        // directory of the AppImage bundle is stored in the APPDIR environment
-        // variable.
+      // qDebug() << "Opening url:" << url;
 
-        QString app_image_dir = qgetenv("APPDIR");
-        qInfo() << "AppImage directory:" << app_image_dir;
+      QDesktopServices::openUrl(QUrl(url));
+    });
 
-        if(app_image_dir.isEmpty())
-          {
-            url += DOC_DIR;
-          }
-        else
-          {
-            url += app_image_dir;
-            url += DOC_DIR;
-          }
-
-        // Finally construct the remainder.
-        qInfo() << "Opening url:" << url;
-        url += "/html/index.html";
-      }
-
-    qInfo() << "Opening url:" << url;
-
-    QDesktopServices::openUrl(QUrl(url));
-  });
-
-  connect(m_ui.wwwHtmlCommandLinkButton, &QPushButton::clicked, []() {
+    connect(m_ui.wwwHtmlCommandLinkButton, &QPushButton::clicked, []() {
 #include <QDesktopServices>
 #include <QUrl>
-    QDesktopServices::openUrl(
-      QUrl("http://msxpertsuite.org/user-manuals/html/minexpert2-user-manual/"
-           "index.html"));
-  });
-}
+      QDesktopServices::openUrl(
+        QUrl("http://www.msxpertsuite.org/user-manuals/minexpert2/html/user-manual/"
+             "index.html"));
+    });
+  }
 
 
 void
