@@ -324,9 +324,10 @@ BaseColorMapPlotCompositeWidget::addColorMap(
   // the trace was obtained in the first place.
   m_plottableProcessingFlowMap[color_map_p] = processing_flow;
 
-  // Now set the name of the sample to the trace label.
-
+  // Note how we do  change the sample name text and its color.
+  // He we do set a new color map plot.
   m_ui.sampleNameLabel->setText(sample_name);
+  setSampleNameColor(color);
 
   mp_plotWidget->replot();
 
