@@ -535,8 +535,18 @@ BasePlotCompositeWidget::showProcessingFlow()
 
   // If this window was never created, then create it now.
   if(mp_processingFlowViewerDlg == nullptr)
-    mp_processingFlowViewerDlg =
-      new ProcessingFlowViewerDlg(mp_parentWnd, "mineXpert");
+    {
+      // qDebug() << "Allocating new ProcessingFlowViewerDlg.";
+
+      mp_processingFlowViewerDlg = new ProcessingFlowViewerDlg(
+        mp_parentWnd, "mineXpert2", plottable_p->pen().color());
+    }
+  else
+    {
+      // qDebug() << "Using existing ProcessingFlowViewerDlg window.";
+
+      mp_processingFlowViewerDlg->updateTraceColor(plottable_p->pen().color());
+    }
 
   mp_processingFlowViewerDlg->setProcessingFlowText(
     processing_flow.toString(0, " "));
@@ -544,6 +554,11 @@ BasePlotCompositeWidget::showProcessingFlow()
   mp_processingFlowViewerDlg->activateWindow();
   mp_processingFlowViewerDlg->raise();
   mp_processingFlowViewerDlg->show();
+  // qDebug() << "Now dialog window should be visible.";
+
+  // qDebug() << "And the window is active:"
+  //          << mp_processingFlowViewerDlg->isActiveWindow()
+  //          << "and visible:" << mp_processingFlowViewerDlg->isVisible();
 }
 
 
@@ -576,6 +591,11 @@ BasePlotCompositeWidget::lastCursorHoveredPoint(const QPointF &pointf)
   m_ui.statusLineEdit->setText(
     QString("(%1,%2)").arg(pointf.x(), 0, 'f', 5).arg(pointf.y(), 0, 'f', 5));
 
+  // The color might have been changed (when setting the intensity value text)
+  // But here we want it in black.
+  QString style = QString("color: black");
+  m_ui.statusLineEdit->setStyleSheet(style);
+
   // qDebug() << "point: (" << pointf.x() << "," << pointf.y() << ")";
 }
 
@@ -600,7 +620,7 @@ BasePlotCompositeWidget::plotRangesChanged(
 
 void
 BasePlotCompositeWidget::xAxisMeasurement(
-  const pappso::BasePlotContext &context, bool with_delta)
+  const pappso::BasePlotContext &context)
 {
   // A measurement was performed, inform the user.
 
@@ -617,57 +637,45 @@ BasePlotCompositeWidget::xAxisMeasurement(
   // that will automagically sort the values. Then use it to craft the
   // message.
 
-#if 0
-
-        // This was the previous version that only cared of X axis movements, but
-        // with the selection polygon we now want to show the full extent of the data:
-        // X axis and Y axis. 
-        QCPRange sorted_range(context.m_xRegionRangeStart, context.m_xRegionRangeEnd);
-
-        QString message = QString("[%1--%2]")
-          .arg(sorted_range.lower, 0, 'f', 3)
-          .arg(sorted_range.upper, 0, 'f', 3);
-
-        if(with_delta)
-          message.append(QString(" - delta: %1").arg(context.m_xDelta, 0, 'f', 3));
-
-        // qDebug() << message;
-
-        m_ui.statusLineEdit->setText(message);
-#endif
-
-
   // First describe the selection polygon.
 
-  QString text = context.m_selectionPolygon.toShort4PointsString();
+  //**QString text = context.m_selectionPolygon.toShort4PointsString();
+  QString text = context.msp_integrationScope->toString();
 
   // Now describe the x|y delta.
 
-  double start;
-  double end;
-
   // We always want the X delta.
-  context.m_selectionPolygon.rangeX(start, end);
-  double delta = abs(end - start);
-  int decimals = pappso::Utils::zeroDecimalsInValue(delta) + 3;
-  text += QString(" -- xDelta: %1").arg(delta, 0, 'f', decimals);
+  //**context.m_selectionPolygon.rangeX(start, end);
+  //**double delta = abs(end - start);
+  double width;
+  if(!context.msp_integrationScope->getWidth(width))
+    qFatal("Failed to get the width.");
 
-  if(delta < 1)
+  int decimals = pappso::Utils::zeroDecimalsInValue(width) + 3;
+  text += QString(" -- xDelta: %1").arg(width, 0, 'f', decimals);
+
+  if(width < 1)
     {
       // And also the inverse of xDelta because it provides a hint to the charge
       // is the xDelta is between to consecutive peaks of an isotopic cluster.
 
-      text += QString(" -- 1/xDelta: %1").arg(1 / delta, 0, 'f', decimals);
+      text += QString(" -- 1/xDelta: %1").arg(1 / width, 0, 'f', decimals);
     }
 
   // We want the Y delta only if the polygon is 2D.
-  if(context.m_selectionPolygon.is2D() && with_delta)
+  //**if(context.m_selectionPolygon.is2D())
+  double height;
+  if(context.msp_integrationScope->getHeight(height))
     {
-      // qDebug() << "Selection polygon is 2D";
-      context.m_selectionPolygon.rangeY(start, end);
-      text += QString(" -- yDelta: %1").arg(end - start, 0, 'f', 2);
+      // qDebug() << "Integration scope is Rect/Poly";
+      //**context.m_selectionPolygon.rangeY(start, end);
+      text += QString(" -- yDelta: %1").arg(height, 0, 'f', 2);
     }
 
+  // The color might have been changed (when setting the intensity value text)
+  // But here we want it in black.
+  QString style = QString("color: black");
+  m_ui.statusLineEdit->setStyleSheet(style);
   m_ui.statusLineEdit->setText(text);
 }
 
@@ -701,7 +709,7 @@ void
 BasePlotCompositeWidget::plotWidgetMouseReleaseEvent(
   [[maybe_unused]] const pappso::BasePlotContext &context)
 {
-  // qDebug();
+  qDebug();
 
   // if(context.m_lastPressedMouseButtonsUponRelease == Qt::NoButton)
   // qDebug() << "no button";
@@ -729,6 +737,36 @@ BasePlotCompositeWidget::plottableSelectionChanged(
 {
   // qDebug() << "graph selection has changed: is it now selected?" <<
   // is_selected;
+
+  if(!is_selected)
+    {
+      // If it is not selected, but there is only one plottable, there is no
+      // ambiguity: show the sample name with color.
+
+      QCPAbstractPlottable *the_plottable_p =
+        plottableToBeUsedAsIntegrationSource();
+
+      if(the_plottable_p == nullptr)
+        {
+          // There are more than one plottable.
+          // Erase the sample name.
+          m_ui.sampleNameLabel->setText("");
+          return;
+        }
+    }
+
+  // At this point we know we we can show the sample name with proper color.
+
+  ProcessingFlow processing_flow = getProcessingFlowForPlottable(plottable_p);
+  MsRunDataSetCstSPtr ms_run_data_set_csp =
+    processing_flow.getMsRunDataSetCstSPtr();
+
+
+  QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
+  m_ui.sampleNameLabel->setText(sample_name);
+
+  QColor color = plottable_p->pen().color();
+  setSampleNameColor(color);
 }
 
 
@@ -1290,10 +1328,18 @@ BasePlotCompositeWidget::mzIntegrationParamsChanged(
 
 
 void
-BasePlotCompositeWidget::newTicIntensityCalculated(double tic_intensity) const
+BasePlotCompositeWidget::newTicIntensityCalculated(double tic_intensity,
+                                                   const QColor &color) const
 {
   m_lastTicIntensity = tic_intensity;
+  QString style;
 
+  if(!color.isValid())
+    style = QString("color: black");
+  else
+    style = QString("color: %1").arg(color.name());
+
+  m_ui.statusLineEdit->setStyleSheet(style);
   m_ui.statusLineEdit->setText("TIC intensity: " +
                                QString("%1").arg(tic_intensity));
 }
@@ -1359,7 +1405,7 @@ BasePlotCompositeWidget::craftAnalysisStanza(
 
   pappso::DataKind data_kind = context.m_dataKind;
 
-  // qDebug() << "data_kind:" << static_cast<int>(data_kind);
+  qDebug() << "data_kind:" << static_cast<int>(data_kind);
 
   DataFormatStringSpecif *specif_p = nullptr;
 
@@ -1558,6 +1604,26 @@ BasePlotCompositeWidget::setPlottingColor(QCPAbstractPlottable *plottable_p,
     qFatal("The color is invalid!");
 
   return mp_plotWidget->setPlottingColor(plottable_p, color);
+
+
+  // Now set the name of the sample to the trace label using the right
+  // color.
+
+  QPalette palette;
+  palette.setColor(QPalette::WindowText, color);
+  m_ui.sampleNameLabel->setPalette(palette);
+}
+
+
+void
+BasePlotCompositeWidget::setSampleNameColor(const QColor &color)
+{
+  if(!color.isValid())
+    qFatal("The color is invalid!");
+
+  QPalette palette;
+  palette.setColor(QPalette::WindowText, color);
+  m_ui.sampleNameLabel->setPalette(palette);
 }
 
 
