@@ -114,8 +114,7 @@ class BasePlotCompositeWidget : public QWidget
   virtual void lastCursorHoveredPoint(const QPointF &pointf);
 
   virtual void plotRangesChanged(const pappso::BasePlotContext &context);
-  virtual void xAxisMeasurement(const pappso::BasePlotContext &context,
-                                bool with_delta = false);
+  void xAxisMeasurement(const pappso::BasePlotContext& context);
 
   virtual void plotWidgetKeyPressEvent(const pappso::BasePlotContext &context);
   virtual void
@@ -128,7 +127,7 @@ class BasePlotCompositeWidget : public QWidget
   void
   mzIntegrationParamsChanged(pappso::MzIntegrationParams mz_integration_params);
 
-  virtual void newTicIntensityCalculated(double tic_intensity) const;
+  virtual void newTicIntensityCalculated(double tic_intensity, const QColor &color) const;
   virtual void resetTicIntensity();
 
   pappso::MzIntegrationParams
@@ -190,7 +189,8 @@ class BasePlotCompositeWidget : public QWidget
                          int scale,
                          int quality = 100) const;
 
-  std::pair<int,int> computePlotSize(std::pair<int,int> requested, std::pair<int,int> actual) const;
+  std::pair<int, int> computePlotSize(std::pair<int, int> requested,
+                                      std::pair<int, int> actual) const;
 
   void showProcessingFlow();
 
@@ -200,6 +200,7 @@ class BasePlotCompositeWidget : public QWidget
   QString craftAnalysisStanza(const pappso::BasePlotContext &context);
 
   void setPlottingColor(QCPAbstractPlottable *plottable_p, const QColor &color);
+  void setSampleNameColor(const QColor &color);
 
   void msLevelValueChanged(int value);
 
@@ -260,7 +261,7 @@ class BasePlotCompositeWidget : public QWidget
   // and the ms run reader.
   std::map<QCPAbstractPlottable *, ProcessingFlow> m_plottableProcessingFlowMap;
 
-  QMenu *mp_mainMenu = nullptr;
+  QMenu *mp_mainMenu         = nullptr;
   QMenu *mp_plotGraphicsMenu = nullptr;
 
   virtual void setupWidget() = 0;
