@@ -39,7 +39,7 @@
 #include <QMenuBar>
 #include <QMenu>
 #include <QDebug>
-
+#include <QtConcurrent>
 
 /////////////////////// pappsomspp includes
 
@@ -956,10 +956,10 @@ BasePlotWnd::integrateToTicIntensity(QCPAbstractPlottable *parent_plottable_p,
 
 void
 BasePlotWnd::integrateToTicIntensity(
-  QCPAbstractPlottable *parent_plottable_p,
-  std::shared_ptr<std::vector<pappso::QualifiedMassSpectrumCstSPtr>>
-    qualified_mass_spectra_sp,
-  const ProcessingFlow &processing_flow)
+    QCPAbstractPlottable *parent_plottable_p,
+    std::shared_ptr<std::vector<pappso::QualifiedMassSpectrumCstSPtr>>
+      qualified_mass_spectra_vector_sp,
+    const ProcessingFlow &processing_flow)
 {
   // qDebug().noquote() << "Integrating to mz with processing flow:"
   //<< processing_flow.toString();
@@ -974,7 +974,7 @@ BasePlotWnd::integrateToTicIntensity(
   // First prepare a vector of QualifiedMassSpectrumCstSPtr
 
   std::size_t qualified_mass_spectra_count = fillInQualifiedMassSpectraVector(
-    ms_run_data_set_csp, qualified_mass_spectra_sp, processing_flow);
+    ms_run_data_set_csp, qualified_mass_spectra_vector_sp, processing_flow);
 
   if(!qualified_mass_spectra_count)
     return;
@@ -989,7 +989,7 @@ BasePlotWnd::integrateToTicIntensity(
   QualifiedMassSpectrumVectorMassDataIntegratorToTicInt
     *mass_data_integrator_p =
       new QualifiedMassSpectrumVectorMassDataIntegratorToTicInt(
-        ms_run_data_set_csp, processing_flow, qualified_mass_spectra_sp);
+        ms_run_data_set_csp, processing_flow, qualified_mass_spectra_vector_sp);
 
   mass_data_integrator_p->setMaxThreadUseCount(
     mp_programWindow->getMaxThreadUseCount());
@@ -1175,8 +1175,11 @@ BasePlotWnd::finishedIntegratingToTicIntensity(
 
   mp_programWindow->logColoredTextToConsole(msg, plot_color);
 
+  // FIXME would be cool to have the right color for the intensity
+  // output in the composite plot widget, depending on the plottable
+  // for which the intensity was calculated.
   mp_programWindow->getPlotWidget(ms_run_data_set_csp, parent_plottable_p)
-    ->newTicIntensityCalculated(tic_intensity);
+    ->newTicIntensityCalculated(tic_intensity, plot_color);
 }
 
 
@@ -1507,12 +1510,40 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
   qDebug() << "Filling-in mass spectra for RT range: " << range_pair.first
            << "-" << range_pair.second;
 
-  std::size_t added_rt_mass_spectra =
-    ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
-      ->addDataSetQualMassSpectraInsideDtRtRange(range_pair.first,
-                                                 range_pair.second,
-                                                 *qualified_mass_spectra_sp,
-                                                 pappso::DataKind::rt);
+  std::size_t added_rt_mass_spectra;
+
+  // Perform this lengthy computation in another thread.
+  QPromise<int> promise;
+  QFuture<int> future = promise.future();
+
+  QScopedPointer<QThread> thread(QThread::create(
+    [&](QPromise<int> promise) {
+      promise.start(); // notifies QFuture that the computation is started
+
+      added_rt_mass_spectra =
+        ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+          ->addDataSetQualMassSpectraInsideDtRtRange(range_pair.first,
+                                                     range_pair.second,
+                                                     *qualified_mass_spectra_sp,
+                                                     pappso::DataKind::rt);
+
+
+      promise.addResult(added_rt_mass_spectra);
+      promise.finish(); // notifies QFuture that the computation is finished
+    },
+    std::move(promise)));
+
+  thread->start();
+  future.waitForFinished(); // blocks until QPromise::finish is called
+  added_rt_mass_spectra = future.result(); // returns added_rt_mass_spectra
+
+  // Original version in the main thread
+  // added_rt_mass_spectra =
+  //   ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+  //     ->addDataSetQualMassSpectraInsideDtRtRange(range_pair.first,
+  //                                                range_pair.second,
+  //                                                *qualified_mass_spectra_sp,
+  //                                                pappso::DataKind::rt);
 
   qDebug() << "Added RT mass spectra:" << added_rt_mass_spectra;
 
@@ -1531,13 +1562,42 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
         << "Detected DT integration, removing mass spectra outside DT range: "
         << range_pair.first << "-" << range_pair.second;
 
-      std::size_t removed_mass_spectra =
-        ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
-          ->removeDataSetQualMassSpectraOutsideDtRtRange(
-            range_pair.first,
-            range_pair.second,
-            *qualified_mass_spectra_sp,
-            pappso::DataKind::dt);
+      std::size_t removed_mass_spectra;
+
+      // Perform this lengthy computation in another thread.
+      QPromise<int> promise;
+      QFuture<int> future = promise.future();
+
+      QScopedPointer<QThread> thread(QThread::create(
+        [&](QPromise<int> promise) {
+          promise.start(); // notifies QFuture that the computation is started
+
+          removed_mass_spectra =
+            ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+              ->removeDataSetQualMassSpectraOutsideDtRtRange(
+                range_pair.first,
+                range_pair.second,
+                *qualified_mass_spectra_sp,
+                pappso::DataKind::dt);
+
+
+          promise.addResult(removed_mass_spectra);
+          promise.finish(); // notifies QFuture that the computation is finished
+        },
+        std::move(promise)));
+
+      thread->start();
+      future.waitForFinished(); // blocks until QPromise::finish is called
+      removed_mass_spectra = future.result(); // returns removed_mass_spectra
+
+      // Original version in the main thread
+      // removed_mass_spectra =
+      // ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+      //                          ->removeDataSetQualMassSpectraOutsideDtRtRange(
+      //                            range_pair.first,
+      //                            range_pair.second,
+      //                            *qualified_mass_spectra_sp,
+      //                            pappso::DataKind::dt);
 
       qDebug() << "Number of mass spectra removed on the basis of DT:"
                << removed_mass_spectra;
