@@ -53,7 +53,7 @@
 #include "ColorSelector.hpp"
 #include "ProgramWindow.hpp"
 #include "LabelledNumberLineEditAction.hpp"
-
+#include "Application.hpp"
 
 namespace msxps
 {
@@ -130,6 +130,10 @@ BaseTracePlotCompositeWidget::BaseTracePlotCompositeWidget(
             else
               qFatal("Programming error.");
           });
+
+  connect(m_ui.pinPointPeakApexPushButton, &QPushButton::clicked, [this]() {
+    m_isPeakApexPinPointing = m_ui.pinPointPeakApexPushButton->isChecked();
+  });
 }
 
 
@@ -316,6 +320,7 @@ BaseTracePlotCompositeWidget::createMainMenu()
       }
 
     // Create the new filter.
+
     pappso::FilterLowIntensitySignalRemovalCstSPtr new_filter_csp =
       std::make_shared<pappso::FilterLowIntensitySignalRemoval>(
         pappso::FilterLowIntensitySignalRemoval(mean, std_dev, threshold));
@@ -474,6 +479,10 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
                 value_vector.push_back(value);
 
               iter_graph_p->setData(key_vector, value_vector, true);
+
+              // Note how we do not change neither the sample name text nor its
+              // color. He we just increment/decrement a trace. We do not set a
+              // new trace.
             }
         }
       // End of
@@ -522,13 +531,10 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
       // the trace was obtained in the first place.
       m_plottableProcessingFlowMap[graph_p] = processing_flow;
 
-      // Now set the name of the sample to the trace label using the right
-      // color.
-
-      QPalette palette;
-      palette.setColor(QPalette::WindowText, local_color);
-      m_ui.sampleNameLabel->setPalette(palette);
+      // Note how we do  change the sample name text and its color.
+      // He we do set a new trace.
       m_ui.sampleNameLabel->setText(sample_name);
+      setSampleNameColor(color);
     }
 
   // qDebug() << "Finished adding trace, asking for the plot widget to replot.";
@@ -549,6 +555,15 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
 void
 BaseTracePlotCompositeWidget::showSavitzkyGolayFilterParamsDlg()
 {
+  // The SavitzkyGolay parameters are saved in the ProcessingFlow that belong
+  // to any given trace. If the settings have been defined already, we can get
+  // them back from the ProcessingFlow via the function filter() below.
+  //
+  // If the settings were not set already, then we can test if they we used at
+  // some previous occasion in the past (by looking into the QSettings).
+  //
+  // If the settings were not found in the QSettings, then we need to ask the
+  // user to actually set them in this specific dialog window.
 
   // First we get the source plottable that might be of interest to the user.
 
@@ -571,6 +586,7 @@ BaseTracePlotCompositeWidget::showSavitzkyGolayFilterParamsDlg()
   // qDebug() << "The source plottable:" << source_plottable_p;
 
   // Set aside SavGolParams that we'll need later.
+  QString parameters;
   pappso::SavGolParams sav_gol_params;
 
   // Now see if we can get the filter from the ProcessingFlow. If it is not
@@ -580,20 +596,50 @@ BaseTracePlotCompositeWidget::showSavitzkyGolayFilterParamsDlg()
   pappso::FilterNameInterfaceCstSPtr filter_csp =
     filter("Savitzky-Golay", source_plottable_p);
 
+  bool parameters_set = false;
+
   if(filter_csp != nullptr)
     {
+      // qDebug() << "Could extract the parameters from the ProcessingFlow:"
+      //          << filter_csp->toString();
+
+      // Make sure we actually have a pappso::FilterSavitzkyGolay filter.
+
       const pappso::FilterSavitzkyGolay *filter_p =
         static_cast<const pappso::FilterSavitzkyGolay *>(filter_csp.get());
 
       if(filter_p != nullptr)
         {
           sav_gol_params = filter_p->getParameters();
+          parameters_set = true;
+
           // qDebug() << "Got parameters from found filter:"
-          //<< sav_gol_params.toString();
+          //          << sav_gol_params.toString();
+        }
+    }
+  else
+    {
+      // qDebug() << "Could not extract the parameters from the
+      // ProcessingFlow.";
+    }
+
+  if(!parameters_set)
+    {
+      // We still have a chance to get parameters by looking into the settings.
+      loadFilterParamsFromSettings("Savitzky-Golay", parameters);
+
+      // qDebug() << "The parameters loaded from the settings:" << parameters;
+
+      if(!parameters.isEmpty())
+        {
+          sav_gol_params.initialize(parameters);
+          parameters_set = true;
         }
     }
 
-  // Else, we keep the default values set in the constructor.
+  // Whatever happens, the SavGolParams will have values because the constructor
+  // of this class provides default values
+  // (see struct PMSPP_LIB_DECL pappso::SavGolParams)
 
   if(mp_savitzkyGolayFilterParamsDlg == nullptr)
     {
@@ -622,6 +668,54 @@ BaseTracePlotCompositeWidget::showSavitzkyGolayFilterParamsDlg()
 }
 
 
+void
+BaseTracePlotCompositeWidget::loadFilterParamsFromSettings(
+  const QString &filter_name, QString &filter_parameters)
+{
+  // qDebug();
+
+  // Try to get the params from the settings, if there are any.
+
+  QSettings settings(static_cast<Application *>(QCoreApplication::instance())
+                       ->getUserConfigSettingsFilePath(),
+                     QSettings::IniFormat);
+
+  settings.beginGroup("FilterParameters");
+
+  filter_parameters = settings.value(filter_name).toString();
+
+  settings.endGroup();
+}
+
+
+void
+BaseTracePlotCompositeWidget::writeFilterParamsToSettings(
+  const QString &filter_name, const QString &filter_parameters)
+{
+  // qDebug();
+
+  QSettings settings(static_cast<Application *>(QCoreApplication::instance())
+                       ->getUserConfigSettingsFilePath(),
+                     QSettings::IniFormat);
+
+  settings.beginGroup("FilterParameters");
+
+  settings.setValue(filter_name, filter_parameters);
+
+  settings.endGroup();
+
+  // #if 0
+
+  QString parameters;
+  loadFilterParamsFromSettings(filter_name, parameters);
+
+  // qDebug() << "The parameters" << filter_name << "just written:" <<
+  // parameters;
+
+  // #endif
+}
+
+
 void
 BaseTracePlotCompositeWidget::savitzkyGolayFilterParamsChanged(
   pappso::SavGolParams sav_gol_params)
@@ -648,33 +742,33 @@ BaseTracePlotCompositeWidget::savitzkyGolayFilterParamsChanged(
       return;
     }
 
-  // Create a new filter
-
-  pappso::FilterSavitzkyGolayCstSPtr filter_csp =
-    std::make_shared<const pappso::FilterSavitzkyGolay>(
-      pappso::FilterSavitzkyGolay(sav_gol_params));
-
-  // Next get the processing flow for that specific graph.
-
-  ProcessingFlow *processing_flow_p =
-    getProcessingFlowPtrForPlottable(source_plottable_p);
-
-  // And finally set the parameters.
-  processing_flow_p->addFilter(filter_csp);
+  // Store the new params to the Settings. These params will be read
+  // when the filter is to be applied.
+  writeFilterParamsToSettings("Savitzky-Golay", sav_gol_params.toString());
 }
 
-
 void
 BaseTracePlotCompositeWidget::runFilter(const QString &filter_name)
 {
   // qDebug();
 
+  // We want to run a filter by its name. The filter is going to be applied to
+  // the trace that is either unique in the widget or selected (if there are
+  // more than one). There are different situations:
+  //
+  // 1. The settings have parameters for a filter by that name. Then, create a
+  // new filter and set it to the ProcessingFlow of the generated filtered trace
+  // if the application of the filter was successful.
+  //
+  // 2. There were no params for a filter by that name. No way, we need to let
+  // the user enter the parameters for the filter.
+
   // First get the plottable for which to apply the filter.
 
   QCPAbstractPlottable *source_plottable_p =
     plottableToBeUsedAsIntegrationSource();
 
-  // qDebug() << "The source plottable:" << source_plottable_p;
+  qDebug() << "The source plottable:" << source_plottable_p;
 
   if(source_plottable_p == nullptr)
     {
@@ -689,27 +783,42 @@ BaseTracePlotCompositeWidget::runFilter(const QString &filter_name)
       return;
     }
 
-  // Now see if we can get a filter by that name and for that plottable.
+  QString filter_parameters;
+  loadFilterParamsFromSettings(filter_name, filter_parameters);
+
+  if(filter_parameters.isEmpty())
+    {
+      // No, there were no filter parameters in the settings. We
+      // cannot go on. If the filter is a SavitzkyGolay filter, then, we can
+      // immeditaly open a dialog window for the user to enter the
+      // parameters.
+
+      if(filter_name == "Savitzky-Golay")
+        {
+          showSavitzkyGolayFilterParamsDlg();
+          return;
+        }
+    }
+
+  // qDebug() << "Could load parameters:" << parameters;
+
+  // We could find the parameters in the settings. Just use them
+  // to craft a filter.
 
   pappso::FilterNameInterfaceCstSPtr filter_csp =
-    filter(filter_name, source_plottable_p);
+    std::make_shared<const pappso::FilterSavitzkyGolay>(
+      QString("%1|%2").arg(filter_name).arg(filter_parameters));
 
   if(filter_csp == nullptr)
     {
-      QMessageBox::information(this,
-                               "Filter not found",
-                               "The filter was not found. Please, check that "
-                               "it was configured properly.",
-                               QMessageBox::StandardButton::Ok,
-                               QMessageBox::StandardButton::NoButton);
+      // qDebug() << "Could not create filter using these parameters.";
 
+      showSavitzkyGolayFilterParamsDlg();
       return;
     }
 
   // qDebug() << "Running filter by name:" << filter_name
-  //<< "with string representation : " << filter_csp->toString();
-
-  // We can go on with the filtering task.
+  //          << "with string representation : " << filter_csp->toString();
 
   pappso::Trace data_trace =
     static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
@@ -730,11 +839,11 @@ BaseTracePlotCompositeWidget::runFilter(const QString &filter_name)
       return;
     }
 
-  // Create a local copy of the processing flow.
-
   ProcessingFlow local_processing_flow =
     getProcessingFlowForPlottable(source_plottable_p);
 
+  local_processing_flow.addFilter(filter_csp);
+
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     getMsRunDataSetCstSPtrForPlottable(source_plottable_p);
 
@@ -750,6 +859,8 @@ BaseTracePlotCompositeWidget::runFilter(const QString &filter_name)
 void
 BaseTracePlotCompositeWidget::runSavitzkyGolayFilter()
 {
+  // qDebug() << "Asked that the Savitzky-Golay filter be run.";
+
   runFilter("Savitzky-Golay");
 }
 
@@ -837,6 +948,50 @@ BaseTracePlotCompositeWidget::plotWidgetKeyReleaseEvent(
 }
 
 
+void
+BaseTracePlotCompositeWidget::plotWidgetMouseReleaseEvent(
+  [[maybe_unused]] const pappso::BasePlotContext &context)
+{
+  // qDebug();
+
+  // if(context.m_lastPressedMouseButtonsUponRelease == Qt::NoButton)
+  // qDebug() << "no button";
+
+  // if(context.m_lastPressedMouseButtonsUponRelease == Qt::LeftButton)
+  // qDebug() << "left button";
+
+  // if(context.m_lastPressedMouseButtonsUponRelease == Qt::RightButton)
+  //{
+  // qDebug() << "right button with context:" << context.toString();
+  //}
+
+  // Now check what keyboard key was being pressed while the mouse
+  // operation was going on.
+
+  // int pressed_key_code = context.m_pressedKeyCode;
+  // qDebug() << "pressed_key_code:" << pressed_key_code;
+
+  // If the user clicks on a trace plot widget while maintaining the 'X' or 'Y'
+  // keys pressed, and if m_isPeakApexPinPointing is true, then the user is
+  // capturing the x axis (or y axis) value in the console.
+
+  if(m_isPeakApexPinPointing)
+    {
+      if(context.m_pressedKeyCode == Qt::Key_X)
+        {
+          mp_parentWnd->getProgramWindow()->logTextToConsole(
+            QString("%1").arg(context.m_lastCursorHoveredPoint.x(), 0, 'f', 4));
+          // qDebug() << "The x value:" << context.m_lastCursorHoveredPoint.x();
+        }
+      else if(context.m_pressedKeyCode == Qt::Key_Y)
+        {
+          mp_parentWnd->getProgramWindow()->logTextToConsole(
+            QString("%1").arg(context.m_lastCursorHoveredPoint.y(), 0, 'f', 4));
+          // qDebug() << "The x value:" << context.m_lastCursorHoveredPoint.y();
+        }
+    }
+}
+
 void
 BaseTracePlotCompositeWidget::moveMouseCursorToNextGraphPoint(
   const pappso::BasePlotContext &context)
