@@ -262,7 +262,8 @@ BaseTracePlotWnd::finalNewTracePlotConfiguration(
   // qDebug()
   //<< processing_flow.getMsRunDataSetCstSPtr()->getMsRunId()->getFileName();
 
-  // qDebug() << "Going to call addTrace on the composite plot widget.";
+  // qDebug() << "Going to call addTrace on the composite plot widget with color:"
+  //          << local_color;
 
   QCPGraph *graph_p = composite_widget_p->addTrace(trace,
                                                    parent_plottable_p,
@@ -442,7 +443,7 @@ BaseTracePlotWnd::duplicateTracePlot(
                         parent_graph_p,
                         composite_widget_p->getMsRunDataSetCstSPtrForPlottable(
                           parent_graph_p),
-                        "Essai sample name",
+                        "Un-named sample",
                         processing_flow,
                         parent_graph_p->pen().color());
                 }
@@ -450,7 +451,7 @@ BaseTracePlotWnd::duplicateTracePlot(
         }
     }
 
-#if 0 
+#if 0
 
 	// This does not work well, but even more: it steals the focus. Not pleasant.
 
