@@ -42,7 +42,8 @@
 
 /////////////////////// pappsomspp includes
 #include <pappsomspp/widget/plotwidget/driftspecmassspeccolormapplotwidget.h>
-
+#include <pappsomspp/processing/combiners/integrationscoperect.h>
+#include <pappsomspp/processing/combiners/integrationscoperhomb.h>
 
 /////////////////////// Local includes
 #include "DriftSpecMassSpecColorMapPlotCompositeWidget.hpp"
@@ -179,28 +180,35 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   // We are getting that signal from a plot widget that operates as a
   // drift spec / mass spec color map plot widget. By essence, the selected
-  // region needs to be two-dimensional, so the selection polygon needs to be
+  // region needs to be two-dimensional, so the integration scope needs to be
   // so.
 
-  // Check if the selection polygon contain meaninful data. We are in a colormap
-  // plot widget, so the selection polygon cannot be in the form of a
-  // mono-dimensional polygon.
+  // Check if the integration scope contain meaninful data. We are in a colormap
+  // plot widget, so the integration scope cannot be in the form of a
+  // mono-dimensional scope.
 
-  if(!context.m_selectionPolygon.is2D())
+  //**if(!context.m_selectionPolygon.is2D())
+  if(!context.msp_integrationScope->is2D())
     {
-      // qDebug() << "The selection polygon cannot be mono-dimensional when "
-      //"selecting for integration from color map";
+      // qDebug() << "The integration scope cannot be mono-dimensional when "
+      //             "selecting for integration from color map";
       return;
     }
   else
     {
-      if(context.m_selectionPolygon.isRectangle())
+      //**if(context.m_selectionPolygon.isRectangle())
+      if(context.msp_integrationScope->isRectangle())
         {
-          // qDebug() << "The selection polygon is rectangle.";
+          // qDebug() << "The integration scope is rectangle.";
         }
       else
         {
-          // qDebug() << "The selection polygon is oblique (skewed).";
+          if(!context.msp_integrationScope->isRhomboid())
+            qFatal(
+              "Cannot be that 2D integration scope is neither rectangle nor "
+              "rhomboid.");
+
+          // qDebug() << "The integration scope is rhomboid (skewed).";
         }
     }
 
@@ -213,7 +221,9 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   double x_range_start;
   double x_range_end;
 
-  context.m_selectionPolygon.rangeX(x_range_start, x_range_end);
+  //**context.m_selectionPolygon.rangeX(x_range_start, x_range_end);
+  context.msp_integrationScope->range(
+    pappso::Axis::x, x_range_start, x_range_end);
 
   // qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
 
@@ -223,7 +233,9 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   double y_range_start;
   double y_range_end;
 
-  context.m_selectionPolygon.rangeY(y_range_start, y_range_end);
+  //**context.m_selectionPolygon.rangeY(y_range_start, y_range_end);
+  context.msp_integrationScope->range(
+    pappso::Axis::y, y_range_start, y_range_end);
 
   // qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
 
@@ -261,7 +273,8 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       return;
     }
 
-  // Create a local copy of the processing flow.
+  // Create a local copy of the processing flow so that we can modify it by
+  // adding the new processing step that describes what we are doing now.
 
   ProcessingFlow local_processing_flow =
     getProcessingFlowForPlottable(plottable_p);
@@ -316,11 +329,20 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   if(x_axis_data_kind == pappso::DataKind::dt)
     {
-      qDebug() << "X axis: dt";
+      // qDebug() << "X axis: dt";
     }
   else if(x_axis_data_kind == pappso::DataKind::mz)
     {
-      qDebug() << "X axis: mz";
+      // qDebug() << "X axis: mz";
+    }
+
+  if(y_axis_data_kind == pappso::DataKind::dt)
+    {
+      // qDebug() << "Y axis: dt";
+    }
+  else if(y_axis_data_kind == pappso::DataKind::mz)
+    {
+      // qDebug() << "Y axis: mz";
     }
 
   if(x_axis_data_kind == pappso::DataKind::dt &&
@@ -343,30 +365,99 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   // Make a local copy of the selection polygon because we might need to
   // transpose it.
 
-  pappso::SelectionPolygon local_selection_polygon = context.m_selectionPolygon;
+  //**pappso::SelectionPolygon local_selection_polygon =
+  // context.m_selectionPolygon;
+
+  // We know the integration scope at this point is 2D and is either Rect or
+  // Rhomb.
+
+  pappso::IntegrationScopeBaseSPtr local_integration_scope_base_sp = nullptr;
+
+  if(context.msp_integrationScope->isRectangle())
+    {
+      // const pappso::IntegrationScopeBase *integration_scope_base_p =
+      // context.msp_integrationScope.get(); const pappso::IntegrationScopeRect
+      // *integration_scope_rect_p = dynamic_cast<const
+      // pappso::IntegrationScopeRect *>(integration_scope_base_p); const
+      // pappso::IntegrationScopeRect *integration_scope_rect_new_p =
+      // integration_scope_rect_p->clone(); pappso::IntegrationScopeRectCstSPtr
+      // integration_scope_rect_new_csp = std::make_shared<const
+      // pappso::IntegrationScopeRect>(*integration_scope_rect_new_p);
+      // pappso::IntegrationScopeRectSPtr integration_scope_rect_new_sp =
+      // std::make_shared<pappso::IntegrationScopeRect>(*integration_scope_rect_new_p);
+      // local_integration_scope_base_sp =
+      // std::static_pointer_cast<pappso::IntegrationScopeBase>(integration_scope_rect_new_sp);
+
+      pappso::IntegrationScopeRectSPtr integration_scope_rect_new_sp =
+        std::make_shared<pappso::IntegrationScopeRect>(
+          *dynamic_cast<const pappso::IntegrationScopeRect *>(
+            context.msp_integrationScope.get()));
+
+      local_integration_scope_base_sp =
+        std::static_pointer_cast<pappso::IntegrationScopeBase>(
+          integration_scope_rect_new_sp);
+    }
+  else if(context.msp_integrationScope->isRhomboid())
+    {
+      //     const pappso::IntegrationScopeBase *integration_scope_base_p =
+      //     context.msp_integrationScope.get(); const
+      //     pappso::IntegrationScopeRhomb *integration_scope_rhomb_p =
+      //     dynamic_cast<const pappso::IntegrationScopeRhomb
+      //     *>(integration_scope_base_p); const pappso::IntegrationScopeRhomb
+      //     *integration_scope_rhomb_new_p =
+      //     integration_scope_rhomb_p->clone();
+      //     pappso::IntegrationScopeRhombCstSPtr
+      //     integration_scope_rhomb_new_csp = std::make_shared<const
+      //     pappso::IntegrationScopeRhomb>(*integration_scope_rhomb_new_p);
+      //     pappso::IntegrationScopeRhombSPtr integration_scope_rhomb_new_sp =
+      //     std::make_shared<pappso::IntegrationScopeRhomb>(*integration_scope_rhomb_new_p);
+      //     local_integration_scope_base_sp =
+      //     std::static_pointer_cast<pappso::IntegrationScopeBase>(integration_scope_rhomb_new_sp);
+      //
+
+      pappso::IntegrationScopeRhombSPtr integration_scope_rhomb_new_sp =
+        std::make_shared<pappso::IntegrationScopeRhomb>(
+          *dynamic_cast<const pappso::IntegrationScopeRhomb *>(
+            context.msp_integrationScope.get()));
+
+      local_integration_scope_base_sp =
+        std::static_pointer_cast<pappso::IntegrationScopeBase>(
+          integration_scope_rhomb_new_sp);
+    }
+  else
+    qFatal(
+      "Cannot be that 2D integration scope is neither rectangle nor "
+      "rhomboid.");
+
+  // qDebug() << "New local integration scope is Rect:"
+  //          << local_integration_scope_base_sp->isRectangle();
+  // qDebug() << "New local integration scope is Rhomb:"
+  //          << local_integration_scope_base_sp->isRhomboid();
 
   if(x_axis_data_kind == pappso::DataKind::mz)
     {
-      // We have to transpose the selection rectangle so that x:MZ and y:DT.
-      local_selection_polygon = local_selection_polygon.transpose();
+      // We transpose to have x::dt and y::mz.
+      //**local_selection_polygon = local_selection_polygon.transpose();
+      local_integration_scope_base_sp->transpose();
     }
   // else
-  // No need to tranpose, we deal with data in the right x:MZ y:DT.
+  // No need to tranpose, we deal with data in the right x::dt and y::mz.
 
-  // qDebug() << "The selection polygon:" << local_selection_polygon.toString();
+  // qDebug() << "The integration scope:"
+  //          << local_integration_scope_base_sp->toString();
 
   // Now we know we have the right selection polygon for x:MZ and y:DT.
 
   processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::dt);
   processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::mz);
 
+  local_integration_scope_base_sp->setDataKindX(pappso::DataKind::dt);
+  local_integration_scope_base_sp->setDataKindY(pappso::DataKind::mz);
 
-  // And now actually set the selection polygon to the step.
+  // And now actually set the integration scope to the step.
 
-  processing_step_sp->setSelectionPolygon(local_selection_polygon);
-
-  // qDebug() << "Selection polygon as set to the step:"
-  //<< processing_step_p->getSelectionPolygon().toString();
+  //**processing_step_sp->setSelectionPolygon(local_selection_polygon);
+  processing_step_sp->setIntegrationScope(local_integration_scope_base_sp);
 
   // We must say what is the data source processing type.
   processing_step_sp->setSrcProcessingType(pappso::Axis::x, "DT");
@@ -478,14 +569,17 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
       // At this point, let's see if we can optimize the integration
       // computation. Indeed, if we know we have an mz range in the selection
-      // polygon, document that range to lower computing time.
+      // polygon, document that range so as to lower computing time.
 
       double mz_range_lower = std::numeric_limits<double>::max();
       double mz_range_upper = std::numeric_limits<double>::min();
 
       // We know we have the x axis being the dt while the mz is the y axis.
 
-      bool res = local_selection_polygon.rangeY(mz_range_lower, mz_range_upper);
+      //**bool res = local_selection_polygon.rangeY(mz_range_lower,
+      // mz_range_upper);
+      bool res = local_integration_scope_base_sp->range(
+        pappso::Axis::y, mz_range_lower, mz_range_upper);
 
       if(!res)
         {
@@ -512,7 +606,6 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // the color maps. The mz integration parameters are now entirely
       // satisfied.
 
-
       // Note that we cannot integrate mass spectra with a high resolution
       // here. We need to reduce the resolution to integer resolution.
       if(m_ui.integrateToDtMzPushButton->isChecked() ||
