@@ -90,9 +90,21 @@ DriftSpecMassSpecColorMapWnd::addColorMapPlot(
 
   // Allocate a DT / m/z -specific composite plot widget.
 
+  // Note that if the data are from the Bruker timsTOF instrument, the mobility
+  // data are not drift times (in milliseconds) but 1/K0. So we need to check
+  // that to set the mobility axis label accordingly.
+
+  QString ion_mobility_axis_label = "drift time (ms)";
+
+  if(ms_run_data_set_csp->getMsRunId()->getMsDataFormat() ==
+     pappso::MsDataFormat::brukerTims)
+    {
+      ion_mobility_axis_label = "inverse mobility (1/K0)";
+    }
+
   DriftSpecMassSpecColorMapPlotCompositeWidget *composite_widget_p =
     new DriftSpecMassSpecColorMapPlotCompositeWidget(
-      this, "drift time (ms)", "m/z");
+      this, ion_mobility_axis_label, "m/z");
 
   return finalNewColorMapPlotConfiguration(composite_widget_p,
                                            double_map_trace_map_sp,
