@@ -43,6 +43,7 @@
 /////////////////////// pappsomspp includes
 #include <pappsomspp/widget/plotwidget/driftspectraceplotwidget.h>
 #include <pappsomspp/processing/combiners/mzintegrationparams.h>
+#include <pappsomspp/processing/combiners/integrationscope.h>
 
 
 /////////////////////// Local includes
@@ -190,18 +191,34 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
   // Make a local copy of the context because we may need to modify it.
   pappso::BasePlotContext local_context = context;
 
-  // Check if the selection polygon contain meaningful data. We are in trace
-  // plot widget, so the selection polygon might be in the form of a
-  // mono-dimensional polygon, although this is not mandatory. But we rely on
-  // the selection polygon to be of 1 or 2 dimension for some optimizations. So,
-  // if the polygon is 2D, convert it to 1D.
+  // Check if the integration scope contains meaningful data. We are in trace
+  // plot widget, so the scope might be in the form of a
+  // mono-dimensional scope, although this is not mandatory.
 
-  if(local_context.m_selectionPolygon.is2D())
-    qDebug() << "Odd situation where the selection polygon is two-dimensional "
-                "and the trace plot selection is mono-dimensional. Converting "
-                "it to a 1D selection polygon.";
+  if(local_context.msp_integrationScope->is2D())
+    {
+      qDebug()
+        << "Odd situation where the selection polygon is two-dimensional "
+           "and the trace plot selection is mono-dimensional. Converting "
+           "it to a 1D selection polygon.";
 
-  local_context.m_selectionPolygon.convertTo1D();
+      //**local_context.msp_integrationScope->convertTo1D();
+      double width;
+      if(!local_context.msp_integrationScope->getWidth(width))
+        qFatal("Failed to get width.");
+
+      QPointF point;
+      if(!local_context.msp_integrationScope->getPoint(point))
+        qFatal("Failed to get point.");
+
+      local_context.msp_integrationScope =
+        std::make_shared<const pappso::IntegrationScopeBase>(
+          pappso::IntegrationScope(point, width));
+    }
+
+  std::const_pointer_cast<pappso::IntegrationScopeBase>(
+    local_context.msp_integrationScope)
+    ->setDataKindX(pappso::DataKind::dt);
 
   // Sanity check.
 
@@ -210,7 +227,9 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
   double range_start;
   double range_end;
 
-  local_context.m_selectionPolygon.rangeX(range_start, range_end);
+  //**local_context.m_selectionPolygon.rangeX(range_start, range_end);
+  local_context.msp_integrationScope->range(
+    pappso::Axis::x, range_start, range_end);
 
   qDebug() << "X axis range:" << range_start << "-" << range_end;
 
@@ -287,7 +306,8 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
       //"valid. Not using it.";
     }
 
-  processing_step_sp->setSelectionPolygon(local_context.m_selectionPolygon);
+  //**processing_step_sp->setSelectionPolygon(local_context.m_selectionPolygon);
+  processing_step_sp->setIntegrationScope(local_context.msp_integrationScope);
 
   // We must say what is the data source processing type.
   processing_step_sp->setSrcProcessingType(pappso::Axis::x, "DT");
