@@ -71,7 +71,8 @@ class DriftSpecTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
 
   virtual void lastCursorHoveredPoint(const QPointF &pointf) override;
 
-  virtual void plotWidgetKeyPressEvent(const pappso::BasePlotContext &context) override;
+  virtual void
+  plotWidgetKeyPressEvent(const pappso::BasePlotContext &context) override;
 
   virtual void moveMouseCursorToNextGraphPoint(
     const pappso::BasePlotContext &context) override;
