@@ -58,6 +58,7 @@
 #include <pappsomspp/processing/combiners/massspectrumpluscombiner.h>
 #include <pappsomspp/processing/combiners/massspectrumminuscombiner.h>
 #include <pappsomspp/widget/plotwidget/massspectraceplotcontext.h>
+#include <pappsomspp/processing/combiners/integrationscope.h>
 
 
 /////////////////////// Local includes
@@ -151,10 +152,10 @@ MassSpecTracePlotCompositeWidget::setupWidget()
   // This connection might be required if the specialized mass spectrum plot
   // widget has some specific data to provide in the specialized context.
   //
-  // connect(static_cast<pappso::MassSpecTracePlotWidget *>(mp_plotWidget),
-  //&pappso::MassSpecTracePlotWidget::mouseReleaseEventSignal,
-  // this,
-  //&MassSpecTracePlotCompositeWidget::plotWidgetMouseReleaseEvent);
+  connect(static_cast<pappso::MassSpecTracePlotWidget *>(mp_plotWidget),
+  &pappso::MassSpecTracePlotWidget::mouseReleaseEventSignal,
+  this,
+  &MassSpecTracePlotCompositeWidget::plotWidgetMouseReleaseEvent);
 
   connect(mp_plotWidget,
           &pappso::MassSpecTracePlotWidget::plottableSelectionChangedSignal,
@@ -761,8 +762,8 @@ void
 MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::MassSpecTracePlotContext &context)
 {
-  // qDebug().noquote() << "ENTER with massplotcontext:" <<
-  // context.toString();
+  // qDebug().noquote() << "ENTER with massspectraceplotcontext:"
+  //                    << context.toString();
 
   // First call the base class that will fill-in the generic fields if the
   // space char was pressed.
@@ -875,9 +876,16 @@ MassSpecTracePlotCompositeWidget::plotWidgetKeyReleaseEvent(
   m_plotWidgetPressedKeyCode = context.m_pressedKeyCode;
 
   // qDebug() << "The key:" << m_plotWidgetPressedKeyCode
-  //<< "the modifiers:" << context.m_keyboardModifiers;
+  // << "the modifiers:" << context.m_keyboardModifiers;
 }
 
+void
+MassSpecTracePlotCompositeWidget::plotWidgetMouseReleaseEvent(const pappso::BasePlotContext &context)
+{
+  // qDebug();
+
+  BaseTracePlotCompositeWidget::plotWidgetMouseReleaseEvent(context);
+}
 
 void
 MassSpecTracePlotCompositeWidget::plotWidgetMassDeconvolution(
@@ -964,23 +972,40 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
 
   // The reference implementation is the
   // TicXicChromTracePlotCompositeWidget one. Look there for all the
-  // explanative comments.
+  // explanatory comments.
 
   // Make a local copy of the context because we may need to modify it.
   pappso::BasePlotContext local_context = context;
 
-  // Check if the selection polygon contain meaningful data. We are in
-  // trace plot widget, so the selection polygon might be in the form of a
-  // mono-dimensional polygon, although this is not mandatory. But we rely
-  // on the selection polygon to be of 1 or 2 dimension for some
-  // optimizations. So, if the polygon is 2D, convert it to 1D.
+  // Check if the integration scope contains meaningful data. We are in trace
+  // plot widget, so the scope might be in the form of a
+  // mono-dimensional scope, although this is not mandatory.
 
-  if(local_context.m_selectionPolygon.is2D())
-    qDebug() << "Odd situation where the selection polygon is two-dimensional "
-                "and the trace plot selection is mono-dimensional. Converting "
-                "it to a 1D selection polygon.";
+  //**if(local_context.m_selectionPolygon.is2D())
+  if(local_context.msp_integrationScope->is2D())
+    {
+      qDebug()
+        << "Odd situation where the selection polygon is two-dimensional "
+           "and the trace plot selection is mono-dimensional. Converting "
+           "it to a 1D selection polygon.";
 
-  local_context.m_selectionPolygon.convertTo1D();
+      //**local_context.msp_integrationScope->convertTo1D();
+      double width;
+      if(!local_context.msp_integrationScope->getWidth(width))
+        qFatal("Failed to get width.");
+
+      QPointF point;
+      if(!local_context.msp_integrationScope->getPoint(point))
+        qFatal("Failed to get point.");
+
+      local_context.msp_integrationScope =
+        std::make_shared<const pappso::IntegrationScopeBase>(
+          pappso::IntegrationScope(point, width));
+    }
+
+  std::const_pointer_cast<pappso::IntegrationScopeBase>(
+    local_context.msp_integrationScope)
+    ->setDataKindX(pappso::DataKind::mz);
 
   // Sanity check.
 
@@ -989,7 +1014,9 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
   double range_start;
   double range_end;
 
-  local_context.m_selectionPolygon.rangeX(range_start, range_end);
+  //**local_context.m_selectionPolygon.rangeX(range_start, range_end);
+  local_context.msp_integrationScope->range(
+    pappso::Axis::x, range_start, range_end);
 
   // qDebug() << "X axis range:" << range_start << "-" << range_end;
 
@@ -1054,7 +1081,8 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
   // Now make sure we document the selection polygon.
   // Now define the graph range for the integration operation.
 
-  processing_step_sp->setSelectionPolygon(local_context.m_selectionPolygon);
+  //**processing_step_sp->setSelectionPolygon(local_context.m_selectionPolygon);
+  processing_step_sp->setIntegrationScope(local_context.msp_integrationScope);
 
   // We must say what is the data source processing type.
   processing_step_sp->setSrcProcessingType(pappso::Axis::x, "MZ");
@@ -1403,6 +1431,10 @@ MassSpecTracePlotCompositeWidget::addTrace(
                   static_cast<QCPGraph *>(iter_plottable_p)
                     ->setData(key_vector, value_vector, true);
                 }
+
+              // Note how we do not change neither the sample name text nor its
+              // color. He we just increment/decrement a trace. We do not set a
+              // new trace.
             }
           else if(mz_integration_params_p->getBinningType() ==
                   pappso::BinningType::ARBITRARY)
@@ -1541,6 +1573,10 @@ MassSpecTracePlotCompositeWidget::addTrace(
                   static_cast<QCPGraph *>(iter_plottable_p)
                     ->setData(key_vector, value_vector, true);
                 }
+
+              // Note how we do not change neither the sample name text nor its
+              // color. He we just increment/decrement a trace. We do not set a
+              // new trace.
             }
         }
       // End of
@@ -1639,9 +1675,10 @@ MassSpecTracePlotCompositeWidget::addTrace(
 
 #endif
 
-      // Now set the name of the sample to the trace label.
-
+      // Note how we do  change the sample name text and its color.
+      // He we do set a new trace.
       m_ui.sampleNameLabel->setText(sample_name);
+      setSampleNameColor(color);
     }
 
   // We need to rescale the axes so that the trace is entirely shown!
@@ -1649,6 +1686,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
 
   mp_plotWidget->replot();
 
+
   // graph_p might be nullptr.
   return static_cast<QCPGraph *>(plottable_p);
 }
