@@ -646,12 +646,14 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
   ProcessingFlow processing_flow;
   processing_flow.setMsRunDataSetCstSPtr(ms_run_data_set_sp);
 
-  ProcessingStep *new_step_p = new ProcessingStep;
-  new_step_p->setSrcProcessingType(pappso::Axis::x, "SOCKET_MZ");
-  new_step_p->setDestProcessingType(ProcessingType("MZ"));
-  new_step_p->setMzIntegrationParams(
+  ProcessingStepSPtr new_step_sp = std::make_shared<ProcessingStep>();
+  new_step_sp->setSrcProcessingType(pappso::Axis::x, "SOCKET_MZ");
+  new_step_sp->setDestProcessingType(ProcessingType("MZ"));
+  new_step_sp->setMzIntegrationParams(
     ms_run_data_set_sp->craftInitialMzIntegrationParams());
-  processing_flow.push_back(new_step_p);
+
+  // Should perform automatically the conversion from non-const to const.
+  processing_flow.push_back(new_step_sp);
 
   // We need to const_cast the step in order to overwrite is
   // MsFragmentationSpec.
