@@ -42,7 +42,9 @@
 
 
 /////////////////////// pappsomspp includes
-
+#include <pappsomspp/processing/combiners/integrationscopebase.h>
+#include <pappsomspp/processing/combiners/integrationscope.h>
+#include <pappsomspp/processing/combiners/integrationscoperect.h>
 
 /////////////////////// Local includes
 #include "MsRunDataSetTableViewWnd.hpp"
@@ -541,8 +543,8 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
   double begin_rt = -1;
   double end_rt   = -1;
 
-  double begin_dt = -1;
-  double end_dt   = -1;
+  double begin_im_value = -1;
+  double end_im_value   = -1;
 
   QItemSelectionModel *selection_model_p =
     mp_msRunDataSetTableView->selectionModel();
@@ -553,8 +555,8 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
   double smallest_rt_value = std::numeric_limits<double>::max();
   double greatest_rt_value = std::numeric_limits<double>::min();
 
-  double smallest_dt_value = std::numeric_limits<double>::max();
-  double greatest_dt_value = std::numeric_limits<double>::min();
+  double smallest_im_value = std::numeric_limits<double>::max();
+  double greatest_im_value = std::numeric_limits<double>::min();
 
   for(int iter = 0; iter < selected_rows_list.size(); ++iter)
     {
@@ -597,13 +599,44 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
       smallest_rt_value = std::min(smallest_rt_value, rt_value);
       greatest_rt_value = std::max(greatest_rt_value, rt_value);
 
+      // Handle the mobility data, either drift time or 1/K0 depending
+      // on the file type.
+      double ion_mobility_value = -1;
 
-      double dt_value = qualified_mass_spectrum_csp->getDtInMilliSeconds();
+      // Get the format of the file, because that will condition the
+      // way we provide mobility values.
 
-      if(dt_value > -1)
+      pappso::MsDataFormat file_format =
+        qualified_mass_spectrum_csp->getMassSpectrumId()
+          .getMsRunIdCstSPtr()
+          ->getMsDataFormat();
+
+      if(file_format == pappso::MsDataFormat::brukerTims)
         {
-          smallest_dt_value = std::min(smallest_dt_value, dt_value);
-          greatest_dt_value = std::max(greatest_dt_value, dt_value);
+          QVariant ion_mobility_variant_value =
+            qualified_mass_spectrum_csp->getParameterValue(
+              pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+
+          if(ion_mobility_variant_value.isValid())
+            {
+              bool ok            = false;
+              ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
+              if(!ok)
+                {
+                  qFatal("Failed to convert QVariant 1/K0 value to double.");
+                }
+            }
+        }
+      else
+        {
+          ion_mobility_value =
+            qualified_mass_spectrum_csp->getDtInMilliSeconds();
+        }
+
+      if(ion_mobility_value > -1)
+        {
+          smallest_im_value = std::min(smallest_im_value, ion_mobility_value);
+          greatest_im_value = std::max(greatest_im_value, ion_mobility_value);
         }
 
       // qDebug() << qSetRealNumberPrecision(10) << "From the table view: "
@@ -631,49 +664,58 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
 
   if(begin_rt == end_rt)
     {
-      qDebug()
-        << "There is only one RT value, crafting an artificial RT range.";
+      // qDebug()
+      //   << "There is only one RT value, crafting an artificial RT range.";
 
       end_rt = pappso::Utils::nearestGreater(end_rt);
     }
 
-  if(smallest_dt_value != std::numeric_limits<double>::max() &&
-     greatest_dt_value != std::numeric_limits<double>::min())
+  if(smallest_im_value != std::numeric_limits<double>::max() &&
+     greatest_im_value != std::numeric_limits<double>::min())
     {
-      begin_dt = smallest_dt_value;
-      qDebug() << "begin_dt:" << begin_dt;
+      begin_im_value = smallest_im_value;
+      // qDebug() << "begin_im_value:" << begin_im_value;
 
-      end_dt = greatest_dt_value;
-      qDebug() << "end_dt:" << end_dt;
+      end_im_value = greatest_im_value;
+      // qDebug() << "end_im_value:" << end_im_value;
 
-      if(begin_dt == end_dt)
+      if(begin_im_value == end_im_value)
         {
-          qDebug()
-            << "There is only one DT value, crafting an artificial DT range.";
+          // qDebug()
+          //   << "There is only one DT value, crafting an artificial DT
+          //   range.";
 
-          end_dt = pappso::Utils::nearestGreater(end_dt);
+          end_im_value = pappso::Utils::nearestGreater(end_im_value);
         }
     }
   else
     {
-      begin_dt = -1;
-      end_dt   = -1;
+      begin_im_value = -1;
+      end_im_value   = -1;
     }
 
-  // At this point, craft the selection polygon.
+  // At this point, craft the integration scope, that will be mono-dimensional
+  // if there is no ion mobility or two-dimensional if there is ion mobility.
 
-  pappso::SelectionPolygon selection_polygon;
+  // pappso::SelectionPolygon selection_polygon;
+  pappso::IntegrationScopeBaseCstSPtr integration_scope_base_csp = nullptr;
 
-  if(begin_dt == -1 || end_dt == -1)
+  if(begin_im_value == -1 || end_im_value == -1)
     {
       // Ion mobility is not a criterion here. Craft a 1D polygon with the RT
       // data only.
 
-      selection_polygon.set1D(begin_rt, end_rt);
+      // selection_polygon.set1D(begin_rt, end_rt);
+      pappso::IntegrationScopeSPtr integration_scope_sp =
+        std::make_shared<pappso::IntegrationScope>(QPointF(begin_rt, 0),
+                                                   fabs(end_rt - begin_rt));
+      integration_scope_base_csp =
+        std::static_pointer_cast<const pappso::IntegrationScopeBase>(
+          integration_scope_sp);
     }
   else
     {
-      // that is, if(begin_dt > -1 && end_dt > -1)
+      // that is, if(begin_im_value > -1 && end_im_value > -1)
 
       // The data set contains ion mobility data.
 
@@ -682,15 +724,25 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
 
       // qDebug() << qSetRealNumberPrecision(50)
       //<< "rt difference:" << end_rt - begin_rt
-      //<< "dt difference:" << end_dt - begin_dt;
+      //<< "dt difference:" << end_im_value - begin_im_value;
 
-      selection_polygon.set2D(QPointF(begin_dt, end_rt),
-                              QPointF(end_dt, end_rt),
-                              QPointF(end_dt, begin_rt),
-                              QPointF(begin_dt, begin_rt));
+      // selection_polygon.set2D(QPointF(begin_im_value, end_rt),
+      //                         QPointF(end_im_value, end_rt),
+      //                         QPointF(end_im_value, begin_rt),
+      //                         QPointF(begin_im_value, begin_rt));
+
+      pappso::IntegrationScopeRectSPtr integration_scope_rect_sp =
+        std::make_shared<pappso::IntegrationScopeRect>(
+          QPointF(begin_im_value, begin_rt),
+          fabs(end_im_value - begin_im_value),
+          fabs(end_rt - begin_rt));
+
+      integration_scope_base_csp =
+        std::static_pointer_cast<const pappso::IntegrationScopeBase>(
+          integration_scope_rect_sp);
     }
 
-  processing_step.setSelectionPolygon(selection_polygon);
+  processing_step.setIntegrationScope(integration_scope_base_csp);
 
   // Note that if the user selects either only one mass spectrum of a given RT
   // or only drift spectra of a given RT, then, begin_rt == end_rt and we cannot
@@ -699,16 +751,16 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
 
   // We need to document the ProcessingType.
 
-  bool is_selection_polygon_2D = selection_polygon.is2D();
-
-  if(is_selection_polygon_2D)
+  // bool is_selection_polygon_2D = selection_polygon.is2D();
+  // if(is_selection_polygon_2D)
+  if(integration_scope_base_csp->is2D())
     {
       // If the selection polygon is bi-dimensional, then that means that
       // there are DT values. So we set dt for the x axis and rt for the y axis
       // (remember we set the axes according to the processing type source name
       // (here DT_RT).
 
-      qDebug() << "The selection polygon is 2D.";
+      // qDebug() << "The integration scope is 2D.";
 
       processing_step.setDataKind(pappso::Axis::x, pappso::DataKind::dt);
       processing_step.setDataKind(pappso::Axis::y, pappso::DataKind::rt);
@@ -720,10 +772,10 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
     }
   else
     {
-      // If the selection polygon is mono-dimensional, then that means that
+      // If the integration scope is mono-dimensional, then that means that
       // there are no DT values. So we set rt for the x axis.
 
-      qDebug() << "The selection polygon is 1D.";
+      // qDebug() << "The integration scope is 1D.";
 
       processing_step.setDataKind(pappso::Axis::x, pappso::DataKind::rt);
       processing_step.setDataKind(pappso::Axis::y, pappso::DataKind::unset);
@@ -752,7 +804,7 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
   else
     qFatal("Programming error.");
 
-  qDebug() << "Finally configured step:" << processing_step.toString();
+  // qDebug() << "Finally configured step:" << processing_step.toString();
 }
 
 
@@ -802,8 +854,8 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
   if(!vector_of_qualified_mass_spectra.size())
     return;
 
-  // qDebug() << "The number of spectra recorded for integration:"
-  //<< vector_of_qualified_mass_spectra.size();
+  qDebug() << "The number of spectra recorded for integration:"
+           << vector_of_qualified_mass_spectra.size();
 
   // We have finished documenting the flow's step, append it to the processing
   // flow.
@@ -811,8 +863,8 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
   // Should perform automatically the conversion from non-const to const.
   local_processing_flow.push_back(step_sp);
 
-  // qDebug().noquote() << "Right before integrating, processing flow:"
-  //<< local_processing_flow.toString();
+  qDebug().noquote() << "Right before integrating, processing flow:"
+                     << local_processing_flow.toString();
 
   // Finally make a shared pointer with the vector of qualified mass spectra.
   using VectorOfQualMassSpecCstSPtrSPtr =
