@@ -253,23 +253,8 @@ MsRunProbeInfoViewerDlg::initialize()
                    mp_plotWidget->xAxis->range().upper);
           });
 
-  // Detect if the user wants to flatten the IM spectra of a frame into a single
-  // spectrum.
-  connect(m_ui.flattenImScansPushButton, &QPushButton::clicked, [&]() {
-    qDebug("Clicked to flatten IM scans.");
-
-    msp_msRunProbeInfo->flattenIonMobilityScans = true;
-
-    if(!validateData())
-      return;
-    else
-      QDialog::accept();
-  });
-
-  // Detect if the user wants to keep all the IM spectra of a frame.
-  connect(m_ui.keepImScansPushButton, &QPushButton::clicked, [&]() {
-    qDebug("Clicked to keep IM scans.");
-    msp_msRunProbeInfo->flattenIonMobilityScans = false;
+  connect(m_ui.loadDataPushButton, &QPushButton::clicked, [&]() {
+    qDebug("Clicked to load data.");
 
     if(!validateData())
       return;
@@ -283,10 +268,12 @@ MsRunProbeInfoViewerDlg::initialize()
   });
 
   connect(m_ui.imOneOverKoGroupBox, &QGroupBox::clicked, [&](bool checked) {
-    m_ui.imScansGroupBox->setChecked(!checked);
+    if(checked)
+      m_ui.imScansGroupBox->setChecked(!checked);
   });
   connect(m_ui.imScansGroupBox, &QGroupBox::clicked, [&](bool checked) {
-    m_ui.imOneOverKoGroupBox->setChecked(!checked);
+    if(checked)
+      m_ui.imOneOverKoGroupBox->setChecked(!checked);
   });
 
   // Now get the TIC chromatogram out of the file in question.
@@ -509,8 +496,16 @@ MsRunProbeInfoViewerDlg::validateData()
       msp_msRunProbeInfo->retentionTimeEndInSeconds   = -1;
     }
 
-  if(m_ui.ionMobilityRangeGroupBox->isChecked())
+  // By default no IM merge unit, that is, ion mobility should
+  // not be a criterion to select data subsets to be loaded.
+  msp_msRunProbeInfo->ionMobilityUnit = IonMobilityUnit::NONE;
+
+  // By default, do not flatten frames, that is, we do not merge IMS scans.
+  msp_msRunProbeInfo->ionMobilityScansMergeRequired = false;
+
+  if(m_ui.ionMobilityGroupBox->isChecked())
     {
+      // Is the user asking to restrict the IM data to some range?
       if(m_ui.imOneOverKoGroupBox->isChecked())
         {
           msp_msRunProbeInfo->ionMobilityUnit = IonMobilityUnit::ONE_OVER_KO;
@@ -527,12 +522,17 @@ MsRunProbeInfoViewerDlg::validateData()
           msp_msRunProbeInfo->ionMobilityScansEnd =
             m_ui.imScansRangeEndSpinBox->value();
         }
-      else
-        qFatal("Cannot be...");
-    }
-  else
-    {
-      msp_msRunProbeInfo->ionMobilityUnit = IonMobilityUnit::NONE;
+
+      // Whatever the IM data restriction above, it is still possible, inside
+      // the restricted IM data range to merge IM data, either by scan count
+      // (every x scans, merge them together) or by 1/K0 window (each time a set
+      // of IM scans span that 1/K0 window, merge them together).
+
+      if(m_ui.mergeImScansCheckBox->isChecked())
+        {
+          msp_msRunProbeInfo->ionMobilityScansMergeRequired =
+            m_ui.mergeImScansCheckBox->isChecked();
+        }
     }
 
   QString ms_levels_to_render = m_ui.msLevelsLineEdit->text();
@@ -541,8 +541,8 @@ MsRunProbeInfoViewerDlg::validateData()
 
   if(!ms_levels_to_render.isEmpty())
     {
-      qDebug("The MS levels line edit widget contains this text: %s",
-             ms_levels_to_render.toLatin1().data());
+      qDebug() << "The MS levels line edit widget contains this text:"
+               << ms_levels_to_render;
 
       QStringList ms_levels_string_list =
         ms_levels_to_render.split(",", Qt::SkipEmptyParts);
