@@ -47,11 +47,22 @@
 /////////////////////// pappsomspp includes
 #include <pappsomspp/msfile/msfileaccessor.h>
 #include <pappsomspp/msrun/msrunreadconfig.h>
+#include <pappsomspp/exception/exceptioninterrupted.h>
 
 
 /////////////////////// Local includes
 #include "MsRunReadTask.hpp"
 #include "../nongui/MassSpecDataFileLoader.hpp"
+// #include <qapplication.h>
+
+
+int MsRunReadTaskMetaTypeId =
+  qRegisterMetaType<msxps::minexpert::MsRunReadTask>(
+    "msxps::minexpert::MsRunReadTask");
+
+int MsRunReadTaskSPtrMetaTypeId =
+  qRegisterMetaType<msxps::minexpert::MsRunReadTaskSPtr>(
+    "msxps::minexpert::MsRunReadTaskSPtr");
 
 
 namespace msxps
@@ -61,12 +72,14 @@ namespace minexpert
 
 
 MsRunReadTask::MsRunReadTask(ProgramWindow *program_window_p)
+  : QObject(), mp_programWindow(program_window_p)
 {
-  // qDebug();
-
-  mp_programWindow = program_window_p;
 }
 
+MsRunReadTask::MsRunReadTask(const MsRunReadTask &other)
+  : QObject(), mp_programWindow(other.mp_programWindow)
+{
+}
 
 MsRunReadTask::~MsRunReadTask()
 {
@@ -81,8 +94,7 @@ MsRunReadTask::readMsRunData(MsRunReadTask *ms_run_read_task_p,
                              MassSpecDataFileLoaderSPtr loader_sp)
 {
   // We need to ensure that we react to a signal that indeed is directed to the
-  // proper MsRunReadTask, because the signal emanates from a generic emitter:
-  // ProgramWindow.
+  // proper MsRunReadTask.
 
   if(this != ms_run_read_task_p)
     return;
@@ -90,13 +102,23 @@ MsRunReadTask::readMsRunData(MsRunReadTask *ms_run_read_task_p,
   // qDebug() << "reading ms run data from thread:" << QThread::currentThread()
   //<< "and this MsRunReadTask:" << this;
 
-  qDebug("Reading MS run data with config: %s\n", 
-         ms_run_read_config.toString().toLatin1().data());
+  // qDebug("Reading MS run data with config: %s\n",
+  //        ms_run_read_config.toString().toLatin1().data());
 
   const auto start_time = std::chrono::steady_clock::now();
 
-  ms_run_reader_sp->readSpectrumCollection2(ms_run_read_config,
-                                            *(loader_sp.get()));
+  try
+    {
+      ms_run_reader_sp->readSpectrumCollection2(ms_run_read_config,
+                                                *(loader_sp.get()));
+    }
+  catch(pappso::ExceptionInterrupted &e)
+    {
+      qDebug() << "Interruption:" << e.what();
+
+      emit finishedReadingMsRunDataSignal(loader_sp->getMsRunDataSet(), 0);
+      return;
+    }
 
   const auto end_time = std::chrono::steady_clock::now();
 
@@ -104,13 +126,20 @@ MsRunReadTask::readMsRunData(MsRunReadTask *ms_run_read_task_p,
     std::chrono::duration_cast<std::chrono::seconds>(end_time - start_time)
       .count();
 
-  qDebug() << "Finished reading spectrum collection. Number of spectra:"
-           << loader_sp->getMsRunDataSet()->size() << "Time used (seconds)"
-           << duration_in_seconds;
+  // qDebug() << "Finished reading spectrum collection. Number of spectra:"
+  //          << loader_sp->getMsRunDataSet()->size()
+  //          << "-- time used (seconds): " << duration_in_seconds;
+
+  //  To debug the fact that the signal is effectively emitted,  which is true
+  //  since the aboutQt dialog shows up.
+  // connect(this, SIGNAL(finishedReadingMsRunDataSignal(MsRunDataSetSPtr,
+  // double)), qApp, SLOT(aboutQt()));
 
   // At this point, emit the signal that we did the job.
   emit finishedReadingMsRunDataSignal(loader_sp->getMsRunDataSet(),
                                       duration_in_seconds);
+
+  // qDebug() << "Emitted the finishedReadingMsRunDataSignal signal.";
 }
 
 
