@@ -50,7 +50,6 @@
 /////////////////////// Local includes
 #include "../nongui/MsRunDataSet.hpp"
 #include "../nongui/MassSpecDataFileLoader.hpp"
-#include "ProgramWindow.hpp"
 
 
 namespace msxps
@@ -66,6 +65,7 @@ class MsRunReadTask : public QObject
 
   public:
   MsRunReadTask(ProgramWindow *program_window_p);
+  MsRunReadTask(const MsRunReadTask &other);
   ~MsRunReadTask();
 
   protected:
@@ -85,6 +85,16 @@ class MsRunReadTask : public QObject
   ProgramWindow *mp_programWindow;
 };
 
+
+typedef std::shared_ptr<MsRunReadTask> MsRunReadTaskSPtr;
+
 } // namespace minexpert
 
 } // namespace msxps
+
+
+Q_DECLARE_METATYPE(msxps::minexpert::MsRunReadTask)
+extern int MsRunReadTaskMetaTypeId;
+
+Q_DECLARE_METATYPE(msxps::minexpert::MsRunReadTaskSPtr)
+extern int MsRunReadTaskSPtrMetaTypeId;
