@@ -63,15 +63,16 @@ class MzIntegrationParamsDlg : public QDialog
 
   public:
   MzIntegrationParamsDlg(QWidget *parent = nullptr);
-  MzIntegrationParamsDlg(QWidget *parent,
-                         const pappso::MzIntegrationParams &mz_integration_params,
-                         const QColor &color);
+  MzIntegrationParamsDlg(
+    QWidget *parent,
+    const pappso::MzIntegrationParams &mz_integration_params,
+    const QColor &color);
   ~MzIntegrationParamsDlg();
 
   void readSettings();
   void writeSettings();
 
-	void	keyPressEvent(QKeyEvent *event);
+  void keyPressEvent(QKeyEvent *event);
 
   void show();
   void setBinningType(pappso::BinningType binningType);
