@@ -55,9 +55,11 @@ namespace minexpert
 
 
 ProcessingFlowViewerDlg::ProcessingFlowViewerDlg(BasePlotWnd *base_plot_wnd_p,
-                                                 const QString &applicationName)
+                                                 const QString &applicationName,
+                          const QColor &color)
   : QDialog(dynamic_cast<QWidget *>(base_plot_wnd_p)),
-    m_applicationName{applicationName}
+    m_applicationName{applicationName},
+    m_color(color)
 {
   if(base_plot_wnd_p == nullptr)
     qFatal("Programming error.");
@@ -120,13 +122,26 @@ ProcessingFlowViewerDlg::setupDialog()
 {
   setWindowTitle(QString("%1 - ProcessingFlow viewer").arg(m_applicationName));
 
+updateTraceColor(m_color);
   readSettings();
 
-
   return true;
 }
 
 
+  void
+ProcessingFlowViewerDlg::updateTraceColor(const QColor &color)
+{
+m_color = color;
+
+  QString style =
+    QString("QPlainTextEdit {border: 2px solid %1;}").arg(m_color.name());
+
+  m_ui.plainTextEdit->setStyleSheet(style);
+
+}
+
+
 void
 ProcessingFlowViewerDlg::setProcessingFlowText(
   const QString &processing_flow_text)
