@@ -59,11 +59,14 @@ class ProcessingFlowViewerDlg : public QDialog
   Q_OBJECT
 
   public:
-  ProcessingFlowViewerDlg(BasePlotWnd *base_plot_wnd_p, const QString &applicationName);
+  ProcessingFlowViewerDlg(BasePlotWnd *base_plot_wnd_p,
+                          const QString &applicationName,
+                          const QColor &color);
 
   virtual ~ProcessingFlowViewerDlg();
 
-	void setProcessingFlowText(const QString &processing_flow_text);
+  void updateTraceColor(const QColor &color);
+  void setProcessingFlowText(const QString &processing_flow_text);
 
   public slots:
 
@@ -73,6 +76,8 @@ class ProcessingFlowViewerDlg : public QDialog
   QString m_applicationName;
   QString m_fileName;
 
+  QColor m_color;
+
   ProgramWindow *mp_programWindow = nullptr;
 
   Q_INVOKABLE void writeSettings();
@@ -86,4 +91,3 @@ class ProcessingFlowViewerDlg : public QDialog
 } // namespace minexpert
 
 } // namespace msxps
-
