@@ -52,6 +52,10 @@
 #include "config.h"
 #include "AboutDlg.hpp"
 
+#include "MsRunLoader.hpp"
+#include "vendor/BrukerTimsTofMsRunLoader.hpp"
+#include "vendor/PwizLiteMsRunLoader.hpp"
+
 #include "OpenMsRunDataSetsDlg.hpp"
 
 #include "../nongui/MassDataIntegrator.hpp"
@@ -124,6 +128,10 @@ class ProgramWindow : public QMainWindow
 
   friend class OpenMsRunDataSetsDlg;
 
+  friend class MsRunLoader;
+  friend class BrukerTimsTofMsRunLoader;
+  friend class PwizLiteMsRunLoader;
+
   ////////////////////////////// public //////////////////////////// /
   ////////////////////////////// public //////////////////////////////
 
@@ -136,22 +144,24 @@ class ProgramWindow : public QMainWindow
   void setMaxThreadUseCount(std::size_t count);
   std::size_t getMaxThreadUseCount();
 
+  void incrementLoadedFileCount();
+
   Q_INVOKABLE bool
   openMassSpectrometryFileDlg(const QString &dir_name = QDir::homePath(),
                               bool full_in_memory     = false);
 
-  Q_INVOKABLE bool
+  Q_INVOKABLE void
   openMassSpectrometryFile(const QString &fileName    = QString(),
                            bool full_in_memory        = false,
                            const QString &sample_name = QString());
-  
+
   bool readMsRunData(pappso::MsFileAccessorSPtr ms_file_accessor_sp,
                      pappso::MsRunReadConfig ms_run_read_config,
                      bool full_in_memory);
- 
-  bool openMassSpectrometryFileFromClipBoard();
 
-  bool openMassSpectrometryFileFromText(const QString &text,
+  void openMassSpectrometryFileFromClipBoard();
+
+  void openMassSpectrometryFileFromText(const QString &text,
                                         const QString &sample_name);
 
   void openAnalysisPreferencesDlg();
@@ -162,6 +172,37 @@ class ProgramWindow : public QMainWindow
 
   std::vector<MsRunDataSetCstSPtr> allSelectedOrUniqueMsRunDataSet();
 
+  /****************************************************************/
+  /* All the windows (dlg or not) */
+  /****************************************************************/
+
+  AboutDlg *showAboutDlg();
+
+  void showOpenMsRunDataSetsWnd();
+  const OpenMsRunDataSetsDlg *getOpenMsRunDataSetsDlg() const;
+
+  void showTicXicChromatogramsWnd();
+  void showMassSpectraWnd();
+  void showDriftSpectraWnd();
+
+  void showXicExtractionWnd();
+
+  void showTicXicChromMassSpecColorMapWnd();
+  void showTicXicChromDriftSpecColorMapWnd();
+  void showDriftSpecMassSpecColorMapWnd();
+
+  void showTaskMonitorWnd();
+
+  void showConsoleWnd();
+
+  void saveWorkspace();
+
+  void showMsRunDataSetTableViewWnd(MsRunDataSetCstSPtr ms_run_data_set_csp,
+                                    const QColor &color);
+
+  void showIsotopicClusterShaperDlg();
+  Q_INVOKABLE void showIsotopicClusterGeneratorDlg();
+
   BaseTracePlotWnd *getPlotWndPtr(const QString &type_name);
   TaskMonitorWnd *getTaskMonitorWnd() const;
 
@@ -243,13 +284,6 @@ class ProgramWindow : public QMainWindow
 
   public slots:
 
-  void finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp,
-                                double duration_seconds);
-
-  void finishedProbingMsRun(MsRunProberSPtr ms_run_prober_sp,
-                            MsRunProbeInfoSPtr ms_run_probe_info_sp,
-                            double duration_seconds);  
-
   void finishedSeedingInitialTicChromatogramAndMsRunDataSetStatistics(
     MassDataIntegrator *mass_data_integrator_p);
 
@@ -273,14 +307,6 @@ class ProgramWindow : public QMainWindow
 
   signals:
 
-  void readMsRunDataSignal(MsRunReadTask *ms_run_read_task_p,
-                           pappso::MsRunReaderSPtr ms_run_reader_sp,
-                           const pappso::MsRunReadConfig &ms_run_reader_config,
-                           std::shared_ptr<MassSpecDataFileLoader> loader_sp);
-
-  void probeMsRunSignal(MsRunProbeTask *ms_run_probe_task_p,
-                        std::shared_ptr<MsRunProber> ms_run_prober_sp);
-
   void seedInitialTicChromatogramAndMsRunDataSetStatisticsSignal(
     MsRunDataSetTreeMassDataIntegratorToRt *mass_data_integrator_p);
 
@@ -398,37 +424,6 @@ class ProgramWindow : public QMainWindow
 
   int selectMsRun(std::vector<pappso::MsRunIdCstSPtr> &ms_run_ids);
 
-  /****************************************************************/
-  /* All the windows (dlg or not) */
-  /****************************************************************/
-
-  AboutDlg *showAboutDlg();
-
-  void showOpenMsRunDataSetsWnd();
-  const OpenMsRunDataSetsDlg *getOpenMsRunDataSetsDlg() const;
-
-  void showTicXicChromatogramsWnd();
-  void showMassSpectraWnd();
-  Q_INVOKABLE void showDriftSpectraWnd();
-
-  void showXicExtractionWnd();
-
-  void showTicXicChromMassSpecColorMapWnd();
-  void showTicXicChromDriftSpecColorMapWnd();
-  void showDriftSpecMassSpecColorMapWnd();
-
-  void showTaskMonitorWnd();
-
-  void showConsoleWnd();
-
-  void saveWorkspace();
-
-  void showMsRunDataSetTableViewWnd(MsRunDataSetCstSPtr ms_run_data_set_csp,
-                                    const QColor &color);
-
-  void showIsotopicClusterShaperDlg();
-  Q_INVOKABLE void showIsotopicClusterGeneratorDlg();
-
   void cancelOperationPushButtonClicked();
 
   void closeEvent(QCloseEvent *event);
