@@ -42,6 +42,8 @@
 
 /////////////////////// pappsomspp includes
 #include <pappsomspp/widget/plotwidget/ticxicchromdriftspeccolormapplotwidget.h>
+#include <pappsomspp/processing/combiners/integrationscoperect.h>
+#include <pappsomspp/processing/combiners/integrationscoperhomb.h>
 
 
 /////////////////////// Local includes
@@ -182,26 +184,37 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
   // qDebug().noquote() << "context:" << context.toString();
 
   // We are getting that signal from a plot widget that operates as a
-  // tic xic chrom / mass spec color map plot widget. By essence, the selected
-  // region needs to be two-dimensional, so the selection polygon needs to be
+  // tic xic chrom / drift spec color map plot widget. By essence, the selected
+  // region needs to be two-dimensional, so the integration scope needs to be
   // so.
 
-  // Check if the selection polygon contain meaninful data. We are in a colormap
-  // plot widget, so the selection polygon cannot be in the form of a
-  // mono-dimensional polygon.
+  // Check if the integration scope contain meaninful data. We are in a colormap
+  // plot widget, so the integration scope cannot be in the form of a
+  // mono-dimensional scope.
 
-  if(!context.m_selectionPolygon.is2D())
+  //**if(!context.m_selectionPolygon.is2D())
+  if(!context.msp_integrationScope->is2D())
     {
-      qDebug() << "The selection polygon cannot be mono-dimensional when "
+      qDebug() << "The integration scope cannot be mono-dimensional when "
                   "selecting for integration from a color map";
       return;
     }
   else
     {
-      if(context.m_selectionPolygon.isRectangle())
-        qDebug() << "The selection polygon is rectangle.";
+      //**if(context.m_selectionPolygon.isRectangle())
+      if(context.msp_integrationScope->isRectangle())
+        {
+          qDebug() << "The integration scope is rectangle.";
+        }
       else
-        qDebug() << "The selection polygon is oblique (skewed).";
+        {
+          if(!context.msp_integrationScope->isRhomboid())
+            qFatal(
+              "Cannot be that 2D integration scope is neither rectangle nor "
+              "rhomboid.");
+
+          qDebug() << "The integration scope is rhomboid (skewed).";
+        }
     }
 
   // Sanity check.
@@ -213,7 +226,11 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
   double x_range_start;
   double x_range_end;
 
-  context.m_selectionPolygon.rangeX(x_range_start, x_range_end);
+  //**context.m_selectionPolygon.rangeX(x_range_start, x_range_end);
+  context.msp_integrationScope->range(
+    pappso::Axis::x, x_range_start, x_range_end);
+
+  // qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
 
   if(x_range_start < 0 && x_range_end < 0)
     return;
@@ -221,7 +238,11 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
   double y_range_start;
   double y_range_end;
 
-  context.m_selectionPolygon.rangeY(y_range_start, y_range_end);
+  //**context.m_selectionPolygon.rangeY(y_range_start, y_range_end);
+  context.msp_integrationScope->range(
+    pappso::Axis::y, y_range_start, y_range_end);
+
+  // qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
 
   if(y_range_start < 0 && y_range_end < 0)
     return;
@@ -312,9 +333,22 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
       ->yAxisDataKind();
 
   if(x_axis_data_kind == pappso::DataKind::dt)
-    qDebug() << "X axis: dt";
+    {
+      // qDebug() << "X axis: dt";
+    }
   else if(x_axis_data_kind == pappso::DataKind::rt)
-    qDebug() << "X axis: rt";
+    {
+      // qDebug() << "X axis: rt";
+    }
+
+  if(y_axis_data_kind == pappso::DataKind::dt)
+    {
+      // qDebug() << "Y axis: dt";
+    }
+  else if(y_axis_data_kind == pappso::DataKind::rt)
+    {
+      // qDebug() << "Y axis: rt";
+    }
 
   if(x_axis_data_kind == pappso::DataKind::dt &&
      y_axis_data_kind != pappso::DataKind::rt)
@@ -336,36 +370,102 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
   // Make a local copy of the selection polygon because we might need to
   // transpose it.
 
-  pappso::SelectionPolygon local_selection_polygon = context.m_selectionPolygon;
+  //**pappso::SelectionPolygon local_selection_polygon =
+  // context.m_selectionPolygon;
 
-  // qDebug() << "The selection polygon:" << local_selection_polygon.toString();
+  // We know the integration scope at this point is 2D and is either Rect or
+  // Rhomb.
+
+  pappso::IntegrationScopeBaseSPtr local_integration_scope_base_sp = nullptr;
+
+  if(context.msp_integrationScope->isRectangle())
+    {
+      // const pappso::IntegrationScopeBase *integration_scope_base_p =
+      //   context.msp_integrationScope.get();
+      // const pappso::IntegrationScopeRect *integration_scope_rect_p =
+      //   dynamic_cast<const pappso::IntegrationScopeRect *>(
+      //     integration_scope_base_p);
+      // const pappso::IntegrationScopeRect *integration_scope_rect_new_p =
+      //   integration_scope_rect_p->clone();
+      // pappso::IntegrationScopeRectCstSPtr integration_scope_rect_new_csp =
+      //   std::make_shared<const pappso::IntegrationScopeRect>(
+      //     *integration_scope_rect_new_p);
+      // pappso::IntegrationScopeRectSPtr integration_scope_rect_new_sp =
+      //   std::make_shared<pappso::IntegrationScopeRect>(
+      //     *integration_scope_rect_new_p);
+      // local_integration_scope_base_sp =
+      //   std::static_pointer_cast<pappso::IntegrationScopeBase>(
+      //     integration_scope_rect_new_sp);
+
+      pappso::IntegrationScopeRectSPtr integration_scope_rect_new_sp =
+        std::make_shared<pappso::IntegrationScopeRect>(
+          *dynamic_cast<const pappso::IntegrationScopeRect *>(
+            context.msp_integrationScope.get()));
+
+      local_integration_scope_base_sp =
+        std::static_pointer_cast<pappso::IntegrationScopeBase>(
+          integration_scope_rect_new_sp);
+    }
+  else if(context.msp_integrationScope->isRhomboid())
+    {
+      // const pappso::IntegrationScopeBase *integration_scope_base_p =
+      //   context.msp_integrationScope.get();
+      // const pappso::IntegrationScopeRhomb *integration_scope_rhomb_p =
+      //   dynamic_cast<const pappso::IntegrationScopeRhomb *>(
+      //     integration_scope_base_p);
+      // const pappso::IntegrationScopeRhomb *integration_scope_rhomb_new_p =
+      //   integration_scope_rhomb_p->clone();
+      // pappso::IntegrationScopeRhombCstSPtr integration_scope_rhomb_new_csp =
+      //   std::make_shared<const pappso::IntegrationScopeRhomb>(
+      //     *integration_scope_rhomb_new_p);
+      // pappso::IntegrationScopeRhombSPtr integration_scope_rhomb_new_sp =
+      //   std::make_shared<pappso::IntegrationScopeRhomb>(
+      //     *integration_scope_rhomb_new_p);
+      // local_integration_scope_base_sp =
+      //   std::static_pointer_cast<pappso::IntegrationScopeBase>(
+      //     integration_scope_rhomb_new_sp);
+
+      pappso::IntegrationScopeRhombSPtr integration_scope_rhomb_new_sp =
+        std::make_shared<pappso::IntegrationScopeRhomb>(
+          *dynamic_cast<const pappso::IntegrationScopeRhomb *>(
+            context.msp_integrationScope.get()));
+
+      local_integration_scope_base_sp =
+        std::static_pointer_cast<pappso::IntegrationScopeBase>(
+          integration_scope_rhomb_new_sp);
+    }
+  else
+    qFatal(
+      "Cannot be that 2D integration scope is neither rectangle nor "
+      "rhomboid.");
+
+  // qDebug() << "New local integration scope is Rect:"
+  //          << local_integration_scope_base_sp->isRectangle();
+  // qDebug() << "New local integration scope is Rhomb:"
+  //          << local_integration_scope_base_sp->isRhomboid();
 
   if(x_axis_data_kind == pappso::DataKind::rt)
     {
-      // qDebug()
-      //<< "The selection polygon has x:rt, transposing the selection polygon.";
-
       // We have to transpose the selection rectangle so that x:DT and y:RT.
-      local_selection_polygon = local_selection_polygon.transpose();
-
-      // qDebug() << "After transposition, the selection polygon:"
-      //<< local_selection_polygon.toString();
+      std::const_pointer_cast<pappso::IntegrationScopeBase>(
+        local_integration_scope_base_sp)
+        ->transpose();
     }
   // else
   // No need to tranpose, we deal with data in the right x:DT y:RT.
 
-  // Now we know we have the right selection polygon for x:DT and y:RT.
+  // Now we know we have the right integration scope for x:DT and y:RT.
 
   processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::dt);
   processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::rt);
 
+  // And now actually set the integration scope to the step.
 
-  // And now actually set the selection polygon to the step.
+  // processing_step_sp->setSelectionPolygon(local_selection_polygon);
+  processing_step_sp->setIntegrationScope(local_integration_scope_base_sp);
 
-  processing_step_sp->setSelectionPolygon(local_selection_polygon);
-
-  // qDebug() << "Selection polygon as set to the step:"
-  //<< processing_step_p->getSelectionPolygon().toString();
+  // qDebug() << "Local integration scope copy:"
+  //          << local_integration_scope_base_sp->toString();
 
   // We must say what is the data source processing type.
   processing_step_sp->setSrcProcessingType(pappso::Axis::x, "DT");
@@ -376,7 +476,7 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
 
   if(m_ui.integrateToRtPushButton->isChecked())
     {
-      qDebug() << "Integrating to XIC chromatogram.";
+      // qDebug() << "Integrating to XIC chromatogram.";
 
       processing_step_sp->setDestProcessingType("RT");
 
@@ -388,7 +488,7 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToDtRtPushButton->isChecked())
     {
-      qDebug() << "Integrating to dt / rt color map.";
+      // qDebug() << "Integrating to dt / rt color map.";
 
       processing_step_sp->setDestProcessingType("DT_RT");
 
@@ -405,19 +505,19 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
     {
       if(m_ui.integrateToMzPushButton->isChecked())
         {
-          qDebug() << "Integrating to mass spectrum.";
+          // qDebug() << "Integrating to mass spectrum.";
 
           processing_step_sp->setDestProcessingType("MZ");
         }
       else if(m_ui.integrateToMzRtPushButton->isChecked())
         {
-          qDebug() << "Integrating to m/z / rt color map.";
+          // qDebug() << "Integrating to m/z / rt color map.";
 
           processing_step_sp->setDestProcessingType("MZ_RT");
         }
       else if(m_ui.integrateToDtMzPushButton->isChecked())
         {
-          qDebug() << "Integrating to dt / m/z color map.";
+          // qDebug() << "Integrating to dt / m/z color map.";
 
           processing_step_sp->setDestProcessingType("DT_MZ");
         }
@@ -438,7 +538,9 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
       if(!mz_integration_params.isValid())
         {
           // qDebug()
-          //<< "The processing flow's default mz integ params are not valid.";
+          //<< "The processing flow's default mz integ params are not valid.
+          // Trying to get the most recent mz integ params " "from the
+          // processing flow. If valid, we may tune them later.";";
 
           mz_integration_params =
             *(local_processing_flow.mostRecentMzIntegrationParams());
@@ -449,24 +551,71 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
       // while it was loaded from file.
       if(!mz_integration_params.isValid())
         {
-          // qDebug() << "The most recent mz integ param are not valid.";
+          // qDebug() << "The most recent mz integ param are not valid. We use "
+          //"the getMsRunDataSetStats to craft new ones that we may "
+          //"tune later.";";
 
           mz_integration_params =
             ms_run_data_set_csp->craftInitialMzIntegrationParams();
         }
+      else
+        {
+          // qDebug() << "The most recent mz integ params are valid. Use them, "
+          //"with potential tuning.";
+        }
 
       if(!mz_integration_params.isValid())
         qFatal(
           "The mz integ params from the ms run data set stats are not valid.");
 
+      // At this point, let's see if we can optimize the integration
+      // computation. Indeed, if we know we have an mz range in the selection
+      // polygon, document that range to lower computing time.
+
+      double mz_range_lower = std::numeric_limits<double>::max();
+      double mz_range_upper = std::numeric_limits<double>::min();
+
+      // We know we have the x axis being the rt while the mz is the y axis.
+
+      // bool res = local_selection_polygon.rangeY(mz_range_lower,
+      // mz_range_upper);
+      bool res = local_integration_scope_base_sp->range(
+        pappso::Axis::y, mz_range_lower, mz_range_upper);
+
+      if(!res)
+        {
+          qFatal("Failed to get the m/z range out of the selection polygon");
+        }
+
+      // At this point, change the values in the mz_integration_params so
+      // that the min and max values match the range, which will ensure that
+      // the integration is the quickest possible as the bins are created in
+      // this range and not in another one that might be larger (if the
+      // integration comes right from the intial TIC, then the range is the
+      // whole range of the mass data in the dataset.
+
+      mz_integration_params.setSmallestMz(mz_range_lower);
+      mz_integration_params.setGreatestMz(mz_range_upper);
+
+      // qDebug() << "After tuning the mz range, mz integration params:"
+      //<< mz_integration_params.toString();
+
+#if 0
+      
+      // This is no more true: we do not force a low resolution computation for
+      // the color maps. The mz integration parameters are now entirely
+      // satisfied.
+      
       // Note that we cannot integrate mass spectra with a high resolution
       // here. We need to reduce the resolution to integer resolution.
       if(m_ui.integrateToDtMzPushButton->isChecked() ||
-         m_ui.integrateToMzRtPushButton->isChecked())
+        m_ui.integrateToMzRtPushButton->isChecked())
         {
-          mz_integration_params.setBinningType(pappso::BinningType::NONE);
-          mz_integration_params.setDecimalPlaces(0);
-        }
+        mz_integration_params.setBinningType(pappso::BinningType::NONE);
+      mz_integration_params.setDecimalPlaces(0);
+    }
+
+#endif
 
       // We finally have mz integ params that we can set to the processing step
       // that we are creating to document this current integration.
@@ -503,7 +652,7 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToDtPushButton->isChecked())
     {
-      qDebug() << "Integrating to drift spectrum.";
+      // qDebug() << "Integrating to drift spectrum.";
 
       processing_step_sp->setDestProcessingType("DT");
 
@@ -515,7 +664,7 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToIntPushButton->isChecked())
     {
-      qDebug() << "Integrating to TIC intensity.";
+      // qDebug() << "Integrating to TIC intensity.";
 
       processing_step_sp->setDestProcessingType("INT");
 
