@@ -63,9 +63,7 @@ class TicXicChromDriftSpecColorMapPlotCompositeWidget
 
   public:
   explicit TicXicChromDriftSpecColorMapPlotCompositeWidget(
-    QWidget *parent,
-    const QString &x_axis_label,
-    const QString &y_axis_label);
+    QWidget *parent, const QString &x_axis_label, const QString &y_axis_label);
 
   virtual ~TicXicChromDriftSpecColorMapPlotCompositeWidget();
 
