@@ -63,9 +63,9 @@ class TicXicChromDriftSpecColorMapWnd : public BaseColorMapPlotWnd
   public:
   // Construction/destruction
   TicXicChromDriftSpecColorMapWnd(QWidget *parent,
-                                 const QString &title,
-                                 const QString &settingsTitle,
-                                 const QString &description = QString());
+                                  const QString &title,
+                                  const QString &settingsTitle,
+                                  const QString &description = QString());
   virtual ~TicXicChromDriftSpecColorMapWnd();
 
   virtual QCPColorMap *
@@ -92,8 +92,8 @@ class TicXicChromDriftSpecColorMapWnd : public BaseColorMapPlotWnd
 
   signals:
 
-  void integrateToDtRtSignal(
-    QualifiedMassSpectrumVectorMassDataIntegratorToRtDt *mass_data_integrator_p);
+  void integrateToDtRtSignal(QualifiedMassSpectrumVectorMassDataIntegratorToRtDt
+                               *mass_data_integrator_p);
 
   protected:
 };
