@@ -63,9 +63,7 @@ class TicXicChromMassSpecColorMapPlotCompositeWidget
 
   public:
   explicit TicXicChromMassSpecColorMapPlotCompositeWidget(
-    QWidget *parent,
-    const QString &x_axis_label,
-    const QString &y_axis_label);
+    QWidget *parent, const QString &x_axis_label, const QString &y_axis_label);
 
   virtual ~TicXicChromMassSpecColorMapPlotCompositeWidget();
 
