@@ -92,8 +92,9 @@ class TicXicChromMassSpecColorMapWnd : public BaseColorMapPlotWnd
 
   signals:
 
-  void integrateToDtRtMzSignal(
-    QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz *mass_data_integrator_p);
+  void
+  integrateToDtRtMzSignal(QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz
+                            *mass_data_integrator_p);
 
   protected:
 };
