@@ -42,6 +42,7 @@
 
 /////////////////////// pappsomspp includes
 #include <pappsomspp/widget/plotwidget/ticxicchromtraceplotwidget.h>
+#include <pappsomspp/processing/combiners/integrationscope.h>
 
 
 /////////////////////// Local includes
@@ -157,7 +158,7 @@ void
 TicXicChromTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::BasePlotContext &context)
 {
-  // qDebug() << "ENTER";
+  // qDebug() << "context:" << context.toString();
 
   // First call the base class that will fill-in the generic fields if the space
   // char was pressed.
@@ -175,7 +176,7 @@ TicXicChromTracePlotCompositeWidget::plotWidgetKeyPressEvent(
 #if 0
 					// We actually do not do this because that part is handled by the base
 					// class.
-		
+
           // We should inform the user if there are more than one plottable.
 
           int plottable_count = mp_plotWidget->plottableCount();
@@ -248,18 +249,34 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
   // Make a local copy of the context because we may need to modify it.
   pappso::BasePlotContext local_context = context;
 
-  // Check if the selection polygon contain meaningful data. We are in trace
-  // plot widget, so the selection polygon might be in the form of a
-  // mono-dimensional polygon, although this is not mandatory. But we rely on
-  // the selection polygon to be of 1 or 2 dimension for some optimizations. So,
-  // if the polygon is 2D, convert it to 1D.
+  // Check if the integration scope contains meaningful data. We are in trace
+  // plot widget, so the scope might be in the form of a
+  // mono-dimensional scope, although this is not mandatory.
 
-  if(local_context.m_selectionPolygon.is2D())
-    qDebug() << "Odd situation where the selection polygon is two-dimensional "
-                "and the trace plot selection is mono-dimensional. Converting "
-                "it to a 1D selection polygon.";
+  if(local_context.msp_integrationScope->is2D())
+    {
+      qDebug()
+        << "Odd situation where the selection polygon is two-dimensional "
+           "and the trace plot selection is mono-dimensional. Converting "
+           "it to a 1D selection polygon.";
 
-  local_context.m_selectionPolygon.convertTo1D();
+      //**local_context.msp_integrationScope->convertTo1D();
+      double width;
+      if(!local_context.msp_integrationScope->getWidth(width))
+        qFatal("Failed to get width.");
+
+      QPointF point;
+      if(!local_context.msp_integrationScope->getPoint(point))
+        qFatal("Failed to get point.");
+
+      local_context.msp_integrationScope =
+        std::make_shared<const pappso::IntegrationScope>(
+          pappso::IntegrationScope(point, width));
+    }
+
+  std::const_pointer_cast<pappso::IntegrationScopeBase>(
+    local_context.msp_integrationScope)
+    ->setDataKindX(pappso::DataKind::rt);
 
   // Sanity check.
 
@@ -268,11 +285,12 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
   double range_start;
   double range_end;
 
-  local_context.m_selectionPolygon.rangeX(range_start, range_end);
+  local_context.msp_integrationScope->range(
+    pappso::Axis::x, range_start, range_end);
 
-  // qDebug() << "selection polygon:" <<
-  // local_context.m_selectionPolygon.toString(); qDebug() << "X axis range:" <<
-  // range_start << "-" << range_end;
+  // qDebug() << "integration scope:" <<
+  // local_context.msp_integrationScope->toString(); qDebug() << "X axis range:"
+  // << range_start << "-" << range_end;
 
   // Having negative retention times does not make any sense.
   if(range_start < 0 && range_end < 0)
@@ -367,7 +385,8 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
 
   // qDebug();
 
-  processing_step_sp->setSelectionPolygon(local_context.m_selectionPolygon);
+  //**processing_step_sp->setSelectionPolygon(local_context.m_selectionPolygon);
+  processing_step_sp->setIntegrationScope(local_context.msp_integrationScope);
 
   // qDebug();
 
