@@ -66,10 +66,9 @@ class TicXicChromTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
   Q_OBJECT
 
   public:
-  explicit TicXicChromTracePlotCompositeWidget(
-    QWidget *parent,
-    const QString &x_axis_label,
-    const QString &y_axis_label);
+  explicit TicXicChromTracePlotCompositeWidget(QWidget *parent,
+                                               const QString &x_axis_label,
+                                               const QString &y_axis_label);
   virtual ~TicXicChromTracePlotCompositeWidget();
 
   public slots:
@@ -84,7 +83,7 @@ class TicXicChromTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
 
   void integrationRequested(const pappso::BasePlotContext &context);
 
-	QString craftAnalysisStanza(const pappso::BasePlotContext &context);
+  QString craftAnalysisStanza(const pappso::BasePlotContext &context);
 
   signals:
 
