@@ -95,6 +95,8 @@ TicXicChromTracePlotWnd::addTracePlot(
     new TicXicChromTracePlotCompositeWidget(
       this, "retention time (min)", "counts (a.u.)");
 
+    qDebug() << "The color:" << color;
+
   QCPGraph *new_graph_p = finalNewTracePlotConfiguration(
     composite_widget_p, trace, processing_flow, color, parent_plottable_p);
 
@@ -277,8 +279,7 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
 void
 TicXicChromTracePlotWnd::integrateToRt(
   QCPAbstractPlottable *parent_plottable_p,
-  std::shared_ptr<std::vector<pappso::QualifiedMassSpectrumCstSPtr>>
-    qualified_mass_spectra_sp,
+  std::shared_ptr<QualifiedMassSpectraVector> qualified_mass_spectra_sp,
   const ProcessingFlow &processing_flow)
 {
   // Get the ms run data set that for the graph we are going to base the
