@@ -40,6 +40,11 @@
 #include <QLineEdit>
 
 
+/////////////////////// pappsomspp includes
+#include <pappsomspp/processing/combiners/integrationscopebase.h>
+#include <pappsomspp/processing/combiners/integrationscoperect.h>
+
+
 /////////////////////// Local includes
 #include "../nongui/globals.hpp"
 #include "XicExtractionWnd.hpp"
@@ -148,20 +153,49 @@ XicExtractionWnd::writeSettings()
 void
 XicExtractionWnd::runPushButtonClicked()
 {
-  bool ok   = false;
-  double mz = m_ui.mzValueLineEdit->text().toDouble(&ok);
-  if(!ok)
-    {
-      statusBar()->showMessage("Please enter a valid m/z value and try again",
-                               2000);
+  QString all_mz_values = m_ui.mzValuesPlainTextEdit->toPlainText();
+  // qDebug() << "All the m/z values:" << all_mz_values;
+  QStringList all_mz_values_string_list =
+    all_mz_values.split(QRegularExpression("\\s+"), Qt::SkipEmptyParts);
 
-      return;
+  if(!all_mz_values_string_list.size())
+    return;
+
+  using MzRangePair = std::pair<double, double>;
+
+  std::vector<MzRangePair> mz_ranges;
+
+  for(int iter = 0; iter < all_mz_values_string_list.size(); ++iter)
+    {
+      bool ok = false;
+
+      double mz_value = all_mz_values_string_list.at(iter).toDouble(&ok);
+
+      if(!ok)
+        {
+          statusBar()->showMessage(
+            "Please enter valid m/z values and try again", 2000);
+
+          return;
+        }
+
+      double delta = mp_precision->delta(mz_value);
+      // qDebug() << "For mz_value:" << mz_value << "the delta is:" << delta;
+
+      // Old version for which the delta was considered full at left
+      // and full at right of the m/z value. This is not very
+      // conventional. The new implementation give a window around
+      // m/z of delta/2 on the left and delta/2 on the right.
+      // mz_ranges.push_back(
+      //   MzRangePair(mz_value - delta, mz_value + delta));
+
+      mz_ranges.push_back(
+        MzRangePair(mz_value - (delta / 2), mz_value + (delta / 2)));
     }
 
-  double delta = mp_precision->delta(mz);
-
-  double mz_start = mz - delta;
-  double mz_end   = mz + delta;
+  // for(auto mz_range : mz_ranges)
+  //   qDebug() << "New range:" << mz_range.first << "--" << mz_range.second
+  //            << "with range span:" << mz_range.second - mz_range.first;
 
   // At this point, get the list of all the mass data files that have their
   // item selected in the OpenSpectraDlg window.
@@ -179,50 +213,68 @@ XicExtractionWnd::runPushButtonClicked()
       return;
     }
 
-  // Craft a 2D selection polygon that will be used to specify the RT and MZ
-  // ranges.
+  // Craft a rectangular integration scope that will be used to specify the RT
+  // and MZ ranges.
 
-  pappso::SelectionPolygon selection_polygon;
+  pappso::IntegrationScopeBaseSPtr integration_scope_base_sp = nullptr;
 
   for(auto &&ms_run_data_set_csp : vector_of_ms_run_data_set_csp)
     {
-      ProcessingFlow processing_flow(ms_run_data_set_csp);
+      for(auto mz_range : mz_ranges)
+        {
+          ProcessingFlow processing_flow(ms_run_data_set_csp);
 
-      ProcessingStepSPtr processing_step_sp =
-        std::make_shared<ProcessingStep>();
+          ProcessingStepSPtr processing_step_sp =
+            std::make_shared<ProcessingStep>();
 
-      processing_step_sp->setSrcProcessingType(pappso::Axis::x, "RT");
-      processing_step_sp->setSrcProcessingType(pappso::Axis::y, "DATA_XIC_MZ");
+          processing_step_sp->setSrcProcessingType(pappso::Axis::x, "RT");
+          processing_step_sp->setSrcProcessingType(pappso::Axis::y,
+                                                   "DATA_XIC_MZ");
 
-      processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::rt);
-      processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::mz);
+          processing_step_sp->setDataKind(pappso::Axis::x,
+                                          pappso::DataKind::rt);
+          processing_step_sp->setDataKind(pappso::Axis::y,
+                                          pappso::DataKind::mz);
 
-      double rt_start = ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
-                          ->getRootNodes()
-                          .front()
-                          ->getQualifiedMassSpectrum()
-                          ->getRtInMinutes();
-      double rt_end = ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
-                        ->getRootNodes()
-                        .back()
-                        ->getQualifiedMassSpectrum()
-                        ->getRtInMinutes();
+          double rt_start = ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+                              ->getRootNodes()
+                              .front()
+                              ->getQualifiedMassSpectrum()
+                              ->getRtInMinutes();
+          double rt_end = ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+                            ->getRootNodes()
+                            .back()
+                            ->getQualifiedMassSpectrum()
+                            ->getRtInMinutes();
 
-      // Craft the selection polygon as a 2D rectangle with x:RT and y:MZ.
-      selection_polygon.set2D(QPointF(rt_start, mz_end),
-                              QPointF(rt_end, mz_end),
-                              QPointF(rt_end, mz_start),
-                              QPointF(rt_start, mz_start));
+          // Craft the integration scope as a 2D rectangle with x:RT and y:MZ.
 
-      processing_step_sp->setDestProcessingType("RT");
+          pappso::IntegrationScopeRectSPtr integration_scope_rect_sp =
+            std::make_shared<pappso::IntegrationScopeRect>(
+              QPointF(rt_start, mz_range.first),
+              (rt_end - rt_start),
+              (mz_range.second - mz_range.first));
 
-      processing_step_sp->setSelectionPolygon(selection_polygon);
+          // qDebug() << "Created scope:" <<
+          // integration_scope_rect_sp->toString();
 
-      // Should perform automatically the conversion from non-const to const.
-      processing_flow.push_back(processing_step_sp);
+          processing_step_sp->setIntegrationScope(
+            std::static_pointer_cast<pappso::IntegrationScopeBase>(
+              integration_scope_rect_sp));
 
-      mp_programWindow->integrateToRt(nullptr, nullptr, processing_flow);
+          processing_step_sp->setDestProcessingType("RT");
+
+          // Should perform automatically the conversion from non-const to
+          // const.
+          processing_flow.push_back(processing_step_sp);
+
+          mp_programWindow->integrateToRt(nullptr, nullptr, processing_flow);
+        }
+      // End of
+      // for(auto mz_range : mz_ranges)
     }
+  // End of
+  // for(auto &&ms_run_data_set_csp : vector_of_ms_run_data_set_csp)
 
   return;
 }
