@@ -128,7 +128,8 @@ class BaseMsRunDataSetTreeNodeVisitor
 
   virtual void setInnermostRanges();
 
-  virtual bool checkMsLevel(pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
+  virtual bool checkMsLevel(
+    pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
 
   virtual bool checkRtRange(
     pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
