@@ -94,7 +94,8 @@ class MassSpectrumTreeNodeCombinerVisitor
 
   const pappso::MapTrace &getMapTrace() const;
 
-  void setMzIntegrationParams(const pappso::MzIntegrationParams &mz_integration_params);
+  void setMzIntegrationParams(
+    const pappso::MzIntegrationParams &mz_integration_params);
   const pappso::MzIntegrationParams &getMzIntegrationParams();
 
   MassSpectrumTreeNodeCombinerVisitor &
@@ -129,8 +130,8 @@ class MassSpectrumTreeNodeCombinerVisitor
   pappso::MzIntegrationParams m_mzIntegrationParams;
   pappso::MapTrace m_mapTrace;
 
-	uint m_verifiedMsFragmentationLevels = 0;
-	bool m_atLeastOneMsFragmentationSpecFailed = false;
+  uint m_verifiedMsFragmentationLevels       = 0;
+  bool m_atLeastOneMsFragmentationSpecFailed = false;
 };
 
 
