@@ -158,13 +158,13 @@ MsRunDataSet::isIonMobilityExperiment() const
 
 
 void
-MsRunDataSet::setFileFormat(pappso::MzFormat file_format)
+MsRunDataSet::setFileFormat(pappso::MsDataFormat file_format)
 {
   m_fileFormat = file_format;
 }
 
 
-pappso::MzFormat
+pappso::MsDataFormat
 MsRunDataSet::getFileFormat() const
 {
   return m_fileFormat;
@@ -333,17 +333,54 @@ MsRunDataSet::mapMassSpectrum(
       found_iter->second.push_back(new_node_p);
     }
 
-  // The drift time is always in milliseconds
-  double dt = qualified_mass_spectrum_csp->getDtInMilliSeconds();
+  // Handle the mobility data, either drift time or 1/K0 depending
+  // on the file type.
 
-  if(dt != -1)
+  double ion_mobility_value = -1;
+
+  // Get the format of the file, because that will condition the
+  // way we provide mobility values.
+
+  pappso::MsDataFormat file_format =
+    qualified_mass_spectrum_csp->getMassSpectrumId()
+      .getMsRunIdCstSPtr()
+      ->getMsDataFormat();
+
+  if(file_format == pappso::MsDataFormat::brukerTims)
+    {
+      QVariant ion_mobility_variant_value =
+        qualified_mass_spectrum_csp->getParameterValue(
+          pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+
+      if(ion_mobility_variant_value.isValid())
+        {
+          bool ok            = false;
+          ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
+          if(!ok)
+            {
+              qFatal("Failed to convert QVariant 1/K0 value to double.");
+            }
+        }
+      // else
+      // the QVariant is not valid, just let ion_mobility_value to be -1.
+    }
+  else
+    {
+      // If the format is not Bruker timsTOF, then we knoow the
+      // ion mobility is stored in the qualified_mass_spectrum_csp as
+      // a drift time.
+      ion_mobility_value = qualified_mass_spectrum_csp->getDtInMilliSeconds();
+    }
+
+  if(ion_mobility_value != -1)
     {
       // A single dt value in the map is associated to a list of ms
       // run data set tree nodes.
 
       using map_iterator = MapDoubleMsRunDataSetTreeNode::iterator;
 
-      map_iterator found_iter = m_dtMsRunDataSetTreeNodeMap.find(dt);
+      map_iterator found_iter =
+        m_dtMsRunDataSetTreeNodeMap.find(ion_mobility_value);
 
       if(found_iter == m_dtMsRunDataSetTreeNodeMap.end())
         {
@@ -354,7 +391,7 @@ MsRunDataSet::mapMassSpectrum(
 
           m_dtMsRunDataSetTreeNodeMap.insert(
             std::pair<double, std::vector<pappso::MsRunDataSetTreeNode *>>(
-              dt, new_node_vector));
+              ion_mobility_value, new_node_vector));
         }
       else
         {
@@ -444,127 +481,5 @@ MsRunDataSet::treeNodeIteratorRangeForRtRange(double start, double end) const
 }
 
 
-#if 0
-
-// This code was never finished. However I discovered that there was a better
-// solution to the fact that we did not want to traverse the whole ms run data
-// set tree to simply integrate *one* mass spectrum.
-
-std::size_t
-MsRunDataSet::addQualifiedMassSpectraInsideDtRtRange(
-  double start,
-  double end,
-  std::size_t ms_level,
-  std::vector<pappso::QualifiedMassSpectrumCstSPtr> &qual_mass_spectra,
-  pappso::DataKind data_kind) const
-{
-  // What we want is add to the qual mass spectra vector, all the mass spectra
-  // that were acquired in the start:end range. That start:end range refers to
-  // either RT or DT depending on the data kind paramater.
-
-  // Determine once for all the right map depending on the data kind.
-
-  MapDoubleQualMassSpectra map;
-
-  if(data_kind == pappso::DataKind::rt)
-    map = m_rtQualMassSpectraMap;
-  else if(data_kind == pappso::DataKind::dt)
-    map = m_dtQualMassSpectraMap;
-
-  std::size_t added_mass_spectra = 0;
-
-  // Search for all the values in the map that are inside the rt_start:ret_end
-  // range.
-
-  using MapIterator = MapDoubleQualMassSpectra::iterator;
-
-  // What is the map item that is not less than rt_start ?
-
-  MapIterator first_iter = map.lower_bound(start);
-
-  if(first_iter == map.end())
-    return 0;
-
-  // What is the map item that is not greater than rt_end ?
-
-  MapIterator last_iter = map.upper_bound(end);
-
-  // Now iterate between the two iterators.
-
-  for(MapIterator iter = first_iter; iter != last_iter; ++iter)
-    {
-      // Each map rt key is associated with a vector of qualmassspectra. We need
-      // to copy the pointers to the vector passed as parameter.
-
-      std::vector<pappso::QualifiedMassSpectrumCstSPtr> cur_vector =
-        iter->second;
-
-      for(auto mass_spectrum_csp : cur_vector)
-        {
-          // But we only do this if the mass spectrum was acquired at the right
-          // MS level.
-          if(mass_spectrum_csp->getMsLevel() == ms_level)
-            qual_mass_spectra.push_back(mass_spectrum_csp);
-          ++added_mass_spectra;
-        }
-    }
-
-  return added_mass_spectra;
-}
-
-
-std::size_t
-MsRunDataSet::removeQualifiedMassSpectraOutsideDtRtRange(
-  double start,
-  double end,
-  std::vector<pappso::QualifiedMassSpectrumCstSPtr> &qual_mass_spectra,
-  pappso::DataKind data_kind) const
-{
-
-  // Determine once for all the right map depending on the data kind.
-
-  MapDoubleQualMassSpectra map;
-
-  if(data_kind == pappso::DataKind::rt)
-    map = m_rtQualMassSpectraMap;
-  else if(data_kind == pappso::DataKind::dt)
-    map = m_dtQualMassSpectraMap;
-
-  std::size_t removed_mass_spectra = 0;
-
-  // We want to remove from the vector of mass spectra all the spectra that are
-  // outside of the [start:end] range.
-
-  auto will_be_iterator_to_end = std::remove_if(
-    qual_mass_spectra.begin(),
-    qual_mass_spectra.end(),
-    [start, end, data_kind](
-      pappso::QualifiedMassSpectrumCstSPtr &mass_spectrum_csp) {
-      if(data_kind == pappso::DataKind::rt)
-        return (mass_spectrum_csp->getRtInSeconds() < start ||
-                mass_spectrum_csp->getRtInSeconds() > end);
-      else if(data_kind == pappso::DataKind::rt)
-        return (mass_spectrum_csp->getDtInMilliSeconds() < start ||
-                mass_spectrum_csp->getDtInMilliSeconds() > end);
-      else
-        qFatal("Programming error.");
-    });
-
-  // At this point, all the mass spectra grouped at will_be_iterator_to_end to
-  // the vector end are the ones we need to erase.
-
-  // Compute the number of spectra that will be removed.
-
-  removed_mass_spectra =
-    std::distance(will_be_iterator_to_end, qual_mass_spectra.end());
-
-  qual_mass_spectra.erase(will_be_iterator_to_end, qual_mass_spectra.end());
-
-  return removed_mass_spectra;
-}
-
-#endif
-
-
 } // namespace minexpert
 } // namespace msxps
