@@ -48,6 +48,7 @@
 #include <QThread>
 
 /////////////////////// pappsomspp includes
+#include <pappsomspp/processing/combiners/integrationscope.h>
 #include <pappsomspp/trace/maptrace.h>
 #include <pappsomspp/processing/combiners/tracepluscombiner.h>
 
@@ -139,17 +140,6 @@ MsRunDataSetTreeMassDataIntegratorToRt::getMsRunDataSetStats() const
 }
 
 
-void
-MsRunDataSetTreeMassDataIntegratorToRt::appendProcessingStep(
-  ProcessingStepCstSPtr processing_step_csp)
-{
-  if(processing_step_csp == nullptr)
-    qFatal("The pointer cannot be nullptr.");
-
-  m_processingFlow.push_back(processing_step_csp);
-}
-
-
 void
 MsRunDataSetTreeMassDataIntegratorToRt::
   seedInitialTicChromatogramAndMsRunDataSetStatistics()
@@ -199,10 +189,15 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   // qDebug() << "Right from the ms run data set, get rt range start:"
   //<< range_start << "and rt range end:" << range_end;
 
-  pappso::SelectionPolygon selection_polygon;
-  selection_polygon.set1D(range_start, range_end);
+  //**pappso::SelectionPolygon selection_polygon;
+  //**selection_polygon.set1D(range_start, range_end);
+  //**step_sp->setSelectionPolygon(selection_polygon);
 
-  step_sp->setSelectionPolygon(selection_polygon);
+  pappso::IntegrationScopeCstSPtr integration_scope_csp =
+    std::make_shared<const pappso::IntegrationScope>(
+      QPointF(range_start, 0), range_end - range_start, pappso::DataKind::rt);
+  step_sp->setIntegrationScope(integration_scope_csp);
+  qDebug() << "Step is:" << step_sp->toString();
 
   // qDebug() << "Created 1D selection polygon:"
   //<< step_p->getSelectionPolygon().toString();
