@@ -42,8 +42,6 @@
 
 /////////////////////// pappsomspp includes
 #include <pappsomspp/msfile/msfileaccessor.h>
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
-#include <pappsomspp/processing/combiners/massspectrumpluscombiner.h>
 
 
 /////////////////////// Local includes
@@ -61,6 +59,7 @@ enum class IonMobilityUnit
   ONE_OVER_KO,
   SCAN,
   DT,
+  LAST,
 };
 
 struct MsRunProbeInfo
@@ -77,14 +76,14 @@ struct MsRunProbeInfo
   double ionMobilityOneOverKoEnd;
   double ionMobilityDtBegin;
   double ionMobilityDtEnd;
+  bool ionMobilityScansMergeRequired;
   std::vector<std::size_t> msLevels;
   std::size_t ms1SpectraCount;
   std::size_t ms2SpectraCount;
   int mzBinCount;
-  double mzBegin               = -1;
-  double mzEnd                 = -1;
-  int mzBinsMergeWindow        = -1;
-  bool flattenIonMobilityScans = false;
+  double mzBegin        = -1;
+  double mzEnd          = -1;
+  int mzBinsMergeWindow = -1;
 
   // Constructors
   MsRunProbeInfo(){};
@@ -102,6 +101,7 @@ struct MsRunProbeInfo
     ionMobilityOneOverKoEnd     = other.ionMobilityOneOverKoEnd;
     ionMobilityDtBegin          = other.ionMobilityDtBegin;
     ionMobilityDtEnd            = other.ionMobilityDtEnd;
+    ionMobilityScansMergeRequired = other.ionMobilityScansMergeRequired;
     msLevels                    = other.msLevels;
     ms1SpectraCount             = other.ms1SpectraCount;
     ms2SpectraCount             = other.ms2SpectraCount;
@@ -109,7 +109,6 @@ struct MsRunProbeInfo
     mzBegin                     = other.mzBegin;
     mzEnd                       = other.mzEnd;
     mzBinsMergeWindow           = other.mzBinsMergeWindow;
-    flattenIonMobilityScans     = other.flattenIonMobilityScans;
   }
   MsRunProbeInfo &
   operator=(const MsRunProbeInfo &other)
@@ -129,6 +128,7 @@ struct MsRunProbeInfo
     ionMobilityOneOverKoEnd     = other.ionMobilityOneOverKoEnd;
     ionMobilityDtBegin          = other.ionMobilityDtBegin;
     ionMobilityDtEnd            = other.ionMobilityDtEnd;
+    ionMobilityScansMergeRequired = other.ionMobilityScansMergeRequired;
     msLevels                    = other.msLevels;
     ms1SpectraCount             = other.ms1SpectraCount;
     ms2SpectraCount             = other.ms2SpectraCount;
@@ -136,7 +136,6 @@ struct MsRunProbeInfo
     mzBegin                     = other.mzBegin;
     mzEnd                       = other.mzEnd;
     mzBinsMergeWindow           = other.mzBinsMergeWindow;
-    flattenIonMobilityScans     = other.flattenIonMobilityScans;
 
     return *this;
   }
@@ -144,9 +143,6 @@ struct MsRunProbeInfo
 
 typedef std::shared_ptr<MsRunProbeInfo> MsRunProbeInfoSPtr;
 
-class MsRunProber;
-
-typedef std::shared_ptr<MsRunProber> MsRunProberSPtr;
 
 typedef std::vector<pappso::QualifiedMassSpectrumCstSPtr>
   QualifiedMassSpectraVector;
@@ -165,15 +161,15 @@ class MsRunProber : public QObject
   public:
   MsRunProber(pappso::MsFileAccessorSPtr ms_file_accessor_sp);
 
-  MsRunProber(const MsRunProber &other);
-
   virtual ~MsRunProber();
 
   pappso::MsFileAccessorSPtr getMsFileAccessorSPtr();
-  
+
   void setReadMsRunFullyInMemory(bool is_full_in_memory);
   bool isReadMsRunFullyInMemory() const;
-  
+
+  bool shouldStop() const;
+
   virtual MsRunProbeInfo probe() = 0;
 
   public slots:
@@ -182,6 +178,7 @@ class MsRunProber : public QObject
 
 
   signals:
+
   void cancelOperationSignal();
 
   void setTaskDescriptionTextSignal(QString text);
@@ -214,6 +211,7 @@ class MsRunProber : public QObject
   private:
 };
 
+typedef std::shared_ptr<MsRunProber> MsRunProberSPtr;
 
 } // namespace minexpert
 
