@@ -216,11 +216,12 @@ ProcessingFlow::innermostRange(
   std::pair<double, double> &out_range,
   std::vector<ProcessingStepCstSPtr> *out_processing_steps_p,
   bool store_only_2d_steps,
-  bool store_only_skewed) const
+  bool store_only_rhomboid) const
 {
   // qDebug() << "Searching for innermost range for source ProcessingType mask:"
-  //<< src_processing_type_mask.toBriefDesc() << "in a flow of" << size()
-  //<< "steps";
+  //          << src_processing_type_mask.toBriefDesc() << "in a flow of" <<
+  //          size()
+  //          << "steps";
 
   // We are asked to get the innermost range for all steps having their
   // processing type matching the processing_type_mask.
@@ -247,7 +248,7 @@ ProcessingFlow::innermostRange(
 
   for(auto &step_csp : *this)
     {
-      // qDebug() << "Iterating in step:" << step_p->toString();
+      // qDebug() << "Iterating in step:" << step_csp->toString();
 
       double range_start;
       double range_end;
@@ -272,17 +273,15 @@ ProcessingFlow::innermostRange(
         }
 
       // Is the currently iterated step mono- or two-dimensional ?
-
-      bool is_2D = step_csp->m_selectionPolygon.is2D();
-
-      if(!is_2D)
+      if(step_csp->msp_integrationScope->is1D())
         {
           // This is the simplest situation, there is only one dimension, the x
           // dimension, that is of interest.
 
           // qDebug() << "That step is 1D";
 
-          step_csp->m_selectionPolygon.rangeX(range_start, range_end);
+          step_csp->msp_integrationScope->range(
+            pappso::Axis::x, range_start, range_end);
 
           if(is_first_iterated_item)
             {
@@ -294,8 +293,8 @@ ProcessingFlow::innermostRange(
 
               if(!store_only_2d_steps)
                 {
-                  // qDebug() << "Even if 1D, setting step as innermost step as
-                  // " "requested.";
+                  // qDebug() << "Step is 1D, setting step as innermost step as"
+                  //             "requested.";
                   innermost_step_csp = step_csp;
                 }
 
@@ -305,28 +304,43 @@ ProcessingFlow::innermostRange(
             {
               // qDebug() << "Not first iterated step.";
 
-              // We now have to update the innermost range values.
+              // This is not the first step we iterate into,
+              // so there are already range values, that we
+              // need to compare with those of this last step so as
+              // to update the innermost range values if necessary.
 
-              bool was_one_dimension_inner = false;
+              // This variable will report if the currently iterated-into step
+              // has range values that make them innermost with respect to
+              // the previous got ones.
+              bool was_at_least_one_range_value_inner = false;
+
+              // If the new x-axis value is greater than the previous one,
+              // then that means that we are reducing the range at the left
+              // side, so this new range start value has to become the new
+              // innermost range start value.
 
               if(range_start > inner_range_start)
                 {
                   inner_range_start = range_start;
 
-                  was_one_dimension_inner = true;
+                  was_at_least_one_range_value_inner = true;
 
                   // qDebug() << "New inner range start:" << inner_range_start;
                 }
 
+              // If the new x-axis value is smaller that the previous one,
+              // then that means that we are reducing the range at the right
+              // side, so this new range end value has to become the new
+              // innmermost range end value.
               if(range_end < inner_range_end)
                 {
                   inner_range_end = range_end;
 
-                  was_one_dimension_inner = true;
+                  was_at_least_one_range_value_inner = true;
                   // qDebug() << "New inner range end:" << inner_range_end;
                 }
 
-              if(was_one_dimension_inner && !store_only_2d_steps)
+              if(was_at_least_one_range_value_inner && !store_only_2d_steps)
                 {
                   // qDebug() << "Even if 1D, setting step as innermost step as
                   // " "requested.";
@@ -338,42 +352,58 @@ ProcessingFlow::innermostRange(
         }
       else
         {
-          // qDebug() << "That step is 2D";
+          // qDebug() << "That step is 2D, either Rect or Rhomb";
 
-          // At this point, we know the selection polygon is 2D, which means we
-          // have to check what actual source types has the iterated step
-          // because we need to know what is the type of the different selection
-          // polygon axes.
+          // At this point, we know the selection polygon is either Rectangle or
+          // Rhomboid, which means we have to check what actual source types the
+          // iterated step has because we need to know what is the type of the
+          // different selection polygon axes. Indeed, we will compare only
+          // range values from the iterated step for the right either horizontal
+          // (X) or vertical (Y) dimension to the ones already encountered in
+          // this iteration over all the steps of the processing flow.
 
           if(step_csp->m_xSrcType.bitMatches(src_processing_type_mask))
             {
               // qDebug() << "Step's m_xSrcType.bitMatches"
-              //<< src_processing_type_mask.toBriefDesc();
+              //          << src_processing_type_mask.toBriefDesc();
 
               // The x axis is the axis we need to check the innermost range of.
+              // Get the range values.
 
-              step_csp->m_selectionPolygon.rangeX(range_start, range_end);
+              //*step_csp->m_selectionPolygon.rangeX(range_start, range_end);
+              step_csp->msp_integrationScope->range(
+                pappso::Axis::x, range_start, range_end);
 
               // qDebug() << "Gotten range values:" << range_start << "-"
-              //<< range_end;
+              //          << range_end;
             }
           else if(step_csp->m_ySrcType.bitMatches(src_processing_type_mask))
             {
               // qDebug() << "Step's m_ySrcType.bitMatches"
-              //<< src_processing_type_mask.toBriefDesc();
+              //          << src_processing_type_mask.toBriefDesc();
 
               // The y axis is the axis we need to check the innermost range of.
+              // Get the range values.
 
-              step_csp->m_selectionPolygon.rangeY(range_start, range_end);
+              //**step_csp->m_selectionPolygon.rangeY(range_start, range_end);
+              step_csp->msp_integrationScope->range(
+                pappso::Axis::y, range_start, range_end);
 
               // qDebug() << "Gotten range values:" << range_start << "-"
-              //<< range_end;
+              //          << range_end;
             }
           else
             qFatal("Programming error.");
 
+          // And now use the gotten range values of the currently iterated step
+          // to establish if that dimension is inner or not.
+
           if(is_first_iterated_item)
             {
+              // Special situation where we are just setting values because
+              // this is the first step that we iterate into and thus
+              // we have no other values to perform comparisons with, whe
+              // just seed the system.
               inner_range_start = range_start;
               inner_range_end   = range_end;
 
@@ -389,15 +419,21 @@ ProcessingFlow::innermostRange(
             {
               // qDebug() << "Not first iterated step.";
 
-              // We now have to update the innermost range values.
+              // This is not the first step we iterate into,
+              // so there are already range values, that we
+              // need to compare with those of this last step so as
+              // to update the innermost range values if necessary.
 
-              bool was_one_dimension_inner = false;
+              // This variable will report if the currently iterated-into step
+              // has range values that make them innermost with respect to
+              // the previous got ones.
+              bool was_at_least_one_range_value_inner = false;
 
               if(range_start > inner_range_start)
                 {
                   inner_range_start = range_start;
 
-                  was_one_dimension_inner = true;
+                  was_at_least_one_range_value_inner = true;
 
                   // qDebug() << "New inner range start:" << inner_range_start;
                 }
@@ -406,15 +442,15 @@ ProcessingFlow::innermostRange(
                 {
                   inner_range_end = range_end;
 
-                  was_one_dimension_inner = true;
+                  was_at_least_one_range_value_inner = true;
 
                   // qDebug() << "New inner range end:" << inner_range_end;
                 }
 
-              if(was_one_dimension_inner)
+              if(was_at_least_one_range_value_inner)
                 {
                   // qDebug() << "Setting step as innermost step.";
-                  innermost_step_csp = step_csp;
+                  // innermost_step_csp = step_csp;
                 }
             }
 
@@ -427,7 +463,10 @@ ProcessingFlow::innermostRange(
 
   // At this point we have iterated in all the steps. To know if at least one
   // step was found matching the src_processing_type_mask, we can test the
-  // inner_range_xxx values against min and max.
+  // inner_range_(start|end) values against NaN.
+
+  // We can't just check innermost_step_csp because the params might
+  // tell not to save the step.
 
   if(std::isnan(inner_range_start) || std::isnan(inner_range_end))
     return false;
@@ -449,7 +488,7 @@ ProcessingFlow::innermostRange(
         {
           // qDebug() << "One innermost step was indeed found.";
 
-          if(!store_only_skewed)
+          if(!store_only_rhomboid)
             {
               // qDebug()
               //<< "The caller wants *all* 2D steps, not only the skewed ones.";
@@ -457,17 +496,19 @@ ProcessingFlow::innermostRange(
             }
           else
             {
-              if(!innermost_step_csp->getSelectionPolygon().isRectangle())
+              if(innermost_step_csp->msp_integrationScope->isRhomboid())
                 {
                   should_store_the_step_in_the_end = true;
                   // qDebug() << "The caller wants *only* the 2D skewed steps
-                  // and " "the step *is* skewed";
+                  // and "
+                  //             "the step *is* rhomboid";
                 }
               // else
-              //{
-              // qDebug() << "The caller wants *only* the 2D skewed steps and "
-              //"the step is *not* skewed";
-              //}
+              //   {
+              //     qDebug() << "The caller wants *only* the 2D rhomboid steps
+              //     "
+              //                 "and sthe step is *not* rhomboid";
+              //   }
             }
         }
       // else
@@ -485,7 +526,7 @@ ProcessingFlow::innermostRange(
       // qDebug() << "Really, the step should be stored.";
 
       // We only push back the range if it has not been found
-      // already. Note that this function might called multiple
+      // already. Note that this function might be called multiple
       // times with different src_processing_type_mask values.
 
       bool was_step_found = false;
@@ -560,26 +601,6 @@ ProcessingFlow::innermostRange(
 
 #endif
 
-
-bool
-ProcessingFlow::hasOnly1DSteps()
-{
-  // We want to know if all the steps in this processing flow have 1D
-  // selection polygons.
-
-  bool is_2D = false;
-
-  for(auto &&step_p : *this)
-    {
-      if(step_p->hasValidSelectionPolygon(is_2D))
-        if(is_2D)
-          return false;
-    }
-
-  return true;
-}
-
-
 size_t
 ProcessingFlow::greatestMsLevel() const
 {
