@@ -46,7 +46,7 @@
 /////////////////////// pappsomspp includes
 #include <pappsomspp/processing/combiners/mzintegrationparams.h>
 #include <pappsomspp/processing/combiners/selectionpolygon.h>
-
+#include <pappsomspp/processing/combiners/integrationscopebase.h>
 
 /////////////////////// Local includes
 #include "ProcessingType.hpp"
@@ -79,13 +79,8 @@ class ProcessingStep
   public:
   ProcessingStep();
 
-  ProcessingStep(const pappso::SelectionPolygon &selection_polygon);
-
   ProcessingStep(const MsFragmentationSpec &ms_fragmentation_spec);
 
-  ProcessingStep(const MsFragmentationSpec &ms_fragmentation_spec,
-                 const pappso::SelectionPolygon selection_polygon);
-
   ProcessingStep(const ProcessingStep &other);
 
   virtual ~ProcessingStep();
@@ -105,11 +100,9 @@ class ProcessingStep
   void setDestProcessingType(const QString &processing_type);
   ProcessingType getDestProcessingType() const;
 
-  void setSelectionPolygon(const pappso::SelectionPolygon &selection_polygon);
-  const pappso::SelectionPolygon &getSelectionPolygon() const;
-  void resetSelectionPolygon();
-
-  bool hasValidSelectionPolygon(bool &is_2D) const;
+  void setIntegrationScope(pappso::IntegrationScopeBaseCstSPtr integration_scope_csp);
+  pappso::IntegrationScopeBaseCstSPtr getIntegrationScope() const;
+  void resetIntegrationScope();
 
   void setDataKind(pappso::Axis axis, pappso::DataKind data_kind);
   pappso::DataKind getDataKind(pappso::Axis axis) const;
@@ -151,12 +144,10 @@ class ProcessingStep
 
   ProcessingType m_destType = ProcessingType("NOT_SET");
 
-  // The QPointF objects in the selection polygon are initialized to
-  // std::numeric_limits<double>::quiet_NaN() for x and y.
-  pappso::SelectionPolygon m_selectionPolygon;
+  pappso::IntegrationScopeBaseCstSPtr msp_integrationScope = nullptr;
 
   // We need to know which kind of data are along the axes that make the
-  // selection polygon.
+  // integration scope..
   pappso::DataKind m_xAxisDataKind = pappso::DataKind::unset;
   pappso::DataKind m_yAxisDataKind = pappso::DataKind::unset;
 
