@@ -45,7 +45,8 @@
 /////////////////////// Local includes
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 #include "ProcessingStep.hpp"
-
+#include <pappsomspp/processing/combiners/integrationscoperect.h>
+#include <pappsomspp/processing/combiners/integrationscoperhomb.h>
 
 int qualifiedMassSpectrumVectorMassDataIntegratorMetaTypeId = qRegisterMetaType<
   msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegrator>(
@@ -664,7 +665,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
 
   // The RT_TO_ANY processing type mask is the most generic mask involving RT
   // data, that encompasses both the 1D RT_ONLY_TO_ANY, but also the 2D
-  // XX_RT_TO_ANY types.
+  // XX_RT_TO_ANY types, with XX being DT or MZ.
 
   // There are two situations:
   //
@@ -672,19 +673,24 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
   // is 1D, then we only are interested in the innermost RT range values.
 
   // 2. when the processing step is 2D, that is, the selection polygon is
-  // rectangle, if any one of the source types matches the mask, then the
-  // correct selection polygon axis range is used.
+  // rectangle. In a 2D selection polygon, each
+  // dimension (horizontal, X ; or vertical, Y) is of a different source kind.
+  // In a RT_DT color map, one source type is RT and the other is DT, for
+  // example. If any one of the source types of the 2D integration scope matches
+  // the mask, then the correct integration scope axis range is used (that is
+  // the dimension that has source type matching the mask).
 
-  // No that when asking that relevant 2D steps be stored in the vector
+  // Note that when asking that relevant 2D steps be stored in the vector
   // m_innermostSteps2D, we specify two options:
   //
-  // 1. That 2D steps be stored *only*.  2. That only 2D steps that have a
-  // skewed selection polygon be stored. This option is easily understood: if a
-  // rectangle is squared, then it is fully described using two ranges, one
-  // range for one axis and another range for the other axis. Only skewed
-  // selection polygons are a challenge for the analysis of the data. The
-  // checkXxRange() functions do monitor the m_innermostSteps2D vector for
-  // skewed selection polygon rectangles.
+  // 1. If only 2D steps need to be stored.
+  //
+  // 2. If only 2D steps that have a rhomboid shape (skewed rectangle) must be
+  // stored. This option is easily understood: if a rectangle is squared, then
+  // it is fully described using two ranges, one range for one axis and another
+  // range for the other axis. Only rhomboid integration scopes are a challenge
+  // for the analysis of the data. The check<DataKind>Range() functions do
+  // monitor the m_innermostSteps2D vector for rhomboid-shaped rectangles.
 
   m_dtRange.first  = std::numeric_limits<double>::quiet_NaN();
   m_dtRange.second = std::numeric_limits<double>::quiet_NaN();
@@ -709,16 +715,30 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
   if(m_processingFlow.innermostRange(
        "ANY_MZ", range_pair, &m_innermostSteps2D, true, true))
     {
-      // qDebug() << "innermost MZ range:" << range_pair.first << "-"
-      //<< range_pair.second;
+      qDebug() << "innermost MZ range:" << range_pair.first << "-"
+               << range_pair.second;
 
       m_mzRange.first  = range_pair.first;
       m_mzRange.second = range_pair.second;
+
+      qDebug() << "m_mzRange.first:" << m_mzRange.first;
+      qDebug() << "m_mzRange.second:" << m_mzRange.second;
     }
 
   m_rtRange.first  = std::numeric_limits<double>::quiet_NaN();
   m_rtRange.second = std::numeric_limits<double>::quiet_NaN();
 
+  // When dealing with steps that are created for a 2D selection in a color map,
+  // for example, there might be skewed selection polygons. For these selection
+  // polygons, a specific procedure needs to be followed to determine if the
+  // qualified mass spectrum's parameters (dt, rt, mz) are contained in the
+  // skewed polygon. But we first need to actually have a list of such skewed
+  // polygons out of the whole list of steps in the processing flow. This is why
+  // we have the following true and true arguments to the function call.
+
+  // See how the skewed selection polygons are searched for in the
+  // checkDtRange() function for example.
+
   // true: only 2D steps
   // true: only skewed 2D steps
   if(m_processingFlow.innermostRange(
@@ -730,6 +750,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
       m_rtRange.first  = range_pair.first;
       m_rtRange.second = range_pair.second;
     }
+
   // Sanity check.
   // It it not possible that not a single step provides a range for RT, given
   // that such a range should have been created upon reading the data from the
@@ -738,7 +759,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
     {
       qFatal(
         "Programming error. Not possible that a processing flow has not a "
-        "single step with a retention range-specifying step.");
+        "single step with a retention time range-specifying step.");
     }
 
   // qDebug() << "The m_innermostSteps2D has now" << m_innermostSteps2D.size()
@@ -747,28 +768,33 @@ QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
 
 
 std::size_t
-QualifiedMassSpectrumVectorMassDataIntegrator::fillInSelectionPolygonSpecs(
-  std::vector<pappso::SelectionPolygonSpec> &selection_polygon_specs)
+QualifiedMassSpectrumVectorMassDataIntegrator::fillInIntegrationScopeSpecs(
+  std::vector<pappso::IntegrationScopeSpec> &integration_scope_specs)
 {
   // qDebug()
   //<< "Fill in the selection polygon specs (MZ-related stuff) vector from "
   //"m_innermostSteps2D with size:"
   //<< m_innermostSteps2D.size();
 
-  // This function is responsible for configuring the selection polygon specs by
-  // looking at m_innermostSteps2D steps that contains MZ data king. These specs
+  // This function is responsible for configuring the integration scope specs by
+  // looking at m_innermostSteps2D steps that contains MZ data kind. These specs
   // are then used by filters to determine if Trace or Mass Spectrum m/z data
   // points are to be used or not for the integration. All this is required to
-  // abide by selection polygons that are not rectangle but are oblique, or
-  // skewed.
+  // abide by selection polygons that are not rectangle but are oblique (a.k.a.
+  // as rhomboid or skewed).
 
   for(auto &&step_csp : m_innermostSteps2D)
     {
-      if(step_csp->getSelectionPolygon().isRectangle())
+      //**if(step_csp->getSelectionPolygon().isRectangle())
+      if(step_csp->getIntegrationScope()->isRectangle())
         {
           // The selection polygon is rectangle, which means that the ranges
           // extracted from the processing flow at construction time are fully
-          // sufficient to characterize the combination work.
+          // sufficient to characterize the combination work. Indeed, a
+          // rectangle can fully be described by two simple ranges: the x-axis
+          // range and the y-axis range. This is not the case with the rhomboid
+          // shape, where it is necessary to look for each m/z value if it is
+          // inside the rhomboid shape or not.
 
           // qDebug() << "Currently iterated step's selection polygon *is* "
           //"rectangle. Skipping it."
@@ -776,6 +802,14 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInSelectionPolygonSpecs(
 
           continue;
         }
+      else if(!step_csp->getIntegrationScope()->isRhomboid())
+        {
+          // At this point we know that the integration scope *must* be of type
+          // Rhomb.
+          qFatal(
+            "The 2D integration scope must be Rhomboid if it is not "
+            "Rectangle.");
+        }
 
       // qDebug() << "Iterating in inner most step 2D:" << step.toString();
 
@@ -784,17 +818,29 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInSelectionPolygonSpecs(
 
       if(step_csp->getSrcProcessingType(pappso::Axis::x).bitMatches("MZ"))
         {
-          // qDebug() << "Step x source type matches MZ";
+          // qDebug() << "Step's x source type matches MZ";
 
+          // We want the integration scope to have MZ as the y-axis dimension.
+          // If this is not the case, we need to transpose the rectangle.
+
+          pappso::IntegrationScopeRhombSPtr local_integration_scope_sp =
+            std::make_shared<pappso::IntegrationScopeRhomb>(
+              static_cast<pappso::IntegrationScopeRhomb>(
+                *(dynamic_cast<const pappso::IntegrationScopeRhomb *>(
+                  step_csp->getIntegrationScope().get()))));
+
+          local_integration_scope_sp->transpose();
+
+          // Now, y:MZ in the transposed scope.
+
+          // But in the original scope, y is still either DT or RT.
           if(step_csp->getSrcProcessingType(pappso::Axis::y).bitMatches("DT"))
             {
               // qDebug() << "We are handling a DT_MZ step source type";
 
               // We want the selection polygon to have x:DT and y:MZ.
-
-              selection_polygon_specs.push_back(pappso::SelectionPolygonSpec(
-                step_csp->getSelectionPolygon().transpose(),
-                pappso::DataKind::dt));
+              integration_scope_specs.push_back(pappso::IntegrationScopeSpec(
+                local_integration_scope_sp, pappso::DataKind::dt));
             }
           else if(step_csp->getSrcProcessingType(pappso::Axis::y)
                     .bitMatches("RT"))
@@ -802,26 +848,28 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInSelectionPolygonSpecs(
               // qDebug() << "We are handling a MZ_RT step source type";
 
               // We want the selection polygon to have x:RT and y:MZ.
-
-              selection_polygon_specs.push_back(pappso::SelectionPolygonSpec(
-                step_csp->getSelectionPolygon().transpose(),
-                pappso::DataKind::rt));
+              integration_scope_specs.push_back(pappso::IntegrationScopeSpec(
+                local_integration_scope_sp, pappso::DataKind::rt));
             }
           else
             qFatal("Programming error.");
         }
       else if(step_csp->getSrcProcessingType(pappso::Axis::y).bitMatches("MZ"))
         {
-          // qDebug() << "Step y source type matches MZ";
+          // qDebug() << "Step's y source type matches MZ";
+
+          // We want the integration scope to have MZ as the y-axis dimension.
+          // No need to transpose.
 
           if(step_csp->getSrcProcessingType(pappso::Axis::x).bitMatches("DT"))
             {
               // qDebug() << "We are handling a DT_MZ step source type";
 
               // We want the selection polygon to have x:DT and y:MZ.
-
-              selection_polygon_specs.push_back(pappso::SelectionPolygonSpec(
-                step_csp->getSelectionPolygon(), pappso::DataKind::dt));
+              integration_scope_specs.push_back(pappso::IntegrationScopeSpec(
+                std::const_pointer_cast<pappso::IntegrationScopeBase>(
+                  step_csp->getIntegrationScope()),
+                pappso::DataKind::dt));
             }
           else if(step_csp->getSrcProcessingType(pappso::Axis::x)
                     .bitMatches("RT"))
@@ -829,9 +877,10 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInSelectionPolygonSpecs(
               // qDebug() << "We are handling a MZ_RT step source type";
 
               // We want the selection polygon to have x:RT and y:MZ.
-
-              selection_polygon_specs.push_back(pappso::SelectionPolygonSpec(
-                step_csp->getSelectionPolygon(), pappso::DataKind::rt));
+              integration_scope_specs.push_back(pappso::IntegrationScopeSpec(
+                std::const_pointer_cast<pappso::IntegrationScopeBase>(
+                  step_csp->getIntegrationScope()),
+                pappso::DataKind::rt));
             }
           else
             qFatal("Programming error.");
@@ -842,7 +891,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInSelectionPolygonSpecs(
   // End of
   // for(auto &&step_csp: m_innermostSteps2D)
 
-  return selection_polygon_specs.size();
+  return integration_scope_specs.size();
 }
 
 
@@ -850,10 +899,41 @@ bool
 QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
 {
-
-  double dt = qualified_mass_spectrum_csp->getDtInMilliSeconds();
   double rt = qualified_mass_spectrum_csp->getRtInMinutes();
 
+  // Handle the mobility data, either drift time or 1/K0 depending
+  // on the file type.
+  double ion_mobility_value = -1;
+
+  // Get the format of the file, because that will condition the
+  // way we provide mobility values.
+
+  pappso::MsDataFormat file_format =
+    qualified_mass_spectrum_csp->getMassSpectrumId()
+      .getMsRunIdCstSPtr()
+      ->getMsDataFormat();
+
+  if(file_format == pappso::MsDataFormat::brukerTims)
+    {
+      QVariant ion_mobility_variant_value =
+        qualified_mass_spectrum_csp->getParameterValue(
+          pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+
+      if(ion_mobility_variant_value.isValid())
+        {
+          bool ok            = false;
+          ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
+          if(!ok)
+            {
+              qFatal("Failed to convert QVariant 1/K0 value to double.");
+            }
+        }
+    }
+  else
+    {
+      ion_mobility_value = qualified_mass_spectrum_csp->getDtInMilliSeconds();
+    }
+
   // qDebug() << "The vector of innermost 2D steps has size:"
   //<< m_innermostSteps2D.size();
 
@@ -871,7 +951,10 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
         {
           // That had DT and RT axes.
 
-          if(!step_csp->getSelectionPolygon().contains(QPointF(dt, rt)))
+          // if(!step_csp->getSelectionPolygon().contains(
+          //      QPointF(ion_mobility_value, rt)))
+          if(!step_csp->getIntegrationScope()->contains(
+               QPointF(ion_mobility_value, rt)))
             {
               // qDebug() << "Checking step:" << step.toString()
               //<< "for qualified mass spectrum with dt|rt:" << dt << "|"
@@ -891,7 +974,10 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
 
           qWarning() << "The selection polygon should have x:DT and y:RT";
 
-          if(!step_csp->getSelectionPolygon().contains(QPointF(rt, dt)))
+          // if(!step_csp->getSelectionPolygon().contains(
+          //      QPointF(rt, ion_mobility_value)))
+          if(!step_csp->getIntegrationScope()->contains(
+               QPointF(rt, ion_mobility_value)))
             {
               // qDebug() << "Checking step:" << step.toString()
               //<< "for qualified mass spectrum with dt|rt:" << dt << "|"
@@ -934,12 +1020,43 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkDtRange(
       return true;
     }
 
-  double dt = qualified_mass_spectrum_csp->getDtInMilliSeconds();
+  // Handle the mobility data, either drift time or 1/K0 depending
+  // on the file type.
+  double ion_mobility_value = -1;
+
+  // Get the format of the file, because that will condition the
+  // way we provide mobility values.
+
+  pappso::MsDataFormat file_format =
+    qualified_mass_spectrum_csp->getMassSpectrumId()
+      .getMsRunIdCstSPtr()
+      ->getMsDataFormat();
+
+  if(file_format == pappso::MsDataFormat::brukerTims)
+    {
+      QVariant ion_mobility_variant_value =
+        qualified_mass_spectrum_csp->getParameterValue(
+          pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+
+      if(ion_mobility_variant_value.isValid())
+        {
+          bool ok            = false;
+          ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
+          if(!ok)
+            {
+              qFatal("Failed to convert QVariant 1/K0 value to double.");
+            }
+        }
+    }
+  else
+    {
+      ion_mobility_value = qualified_mass_spectrum_csp->getDtInMilliSeconds();
+    }
 
   // qDebug() << qSetRealNumberPrecision(10) << "dt range:" << m_dtRange.first
   //<< "-" << m_dtRange.second << "The mass spectrum dt value:" << dt;
 
-  if(dt == -1)
+  if(ion_mobility_value == -1)
     {
       // There is no DT range data in the mass spectrum, which means DT cannot
       // be  a criterion to filter mass spectra. Return true so that the mass
@@ -947,7 +1064,8 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkDtRange(
       return true;
     }
 
-  if(!(dt >= m_dtRange.first && dt <= m_dtRange.second))
+  if(!(ion_mobility_value >= m_dtRange.first &&
+       ion_mobility_value <= m_dtRange.second))
     {
       // qDebug() << "Returning false on the check of the dt range.";
       return false;
