@@ -97,11 +97,12 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
 
   const pappso::MapTrace &getMapTrace() const;
 
-  void setMaxThreadUseCount(std::size_t count);
-  std::size_t getMaxThreadUseCount();
+  virtual void setMaxThreadUseCount(std::size_t count);
+  virtual std::size_t getMaxThreadUseCount();
 
   public slots:
 
+  virtual void integrate() = 0;
   void cancelOperation();
 
 
@@ -140,8 +141,6 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
 
   std::vector<ProcessingStepCstSPtr> m_innermostSteps2D;
 
-  std::vector<pappso::SelectionPolygonSpec> m_selectionPolygonSpecs;
-
   std::pair<double, double> m_dtRange =
     std::pair<double, double>(std::numeric_limits<double>::quiet_NaN(),
                               std::numeric_limits<double>::quiet_NaN());
@@ -168,8 +167,8 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
 
   virtual void setInnermostRanges();
 
-  virtual std::size_t fillInSelectionPolygonSpecs(
-    std::vector<pappso::SelectionPolygonSpec> &selection_polygon_specs);
+  virtual std::size_t fillInIntegrationScopeSpecs(
+    std::vector<pappso::IntegrationScopeSpec> &integration_scope_specs);
 
   virtual bool checkMsLevel(
     pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
@@ -226,4 +225,3 @@ extern int qualifiedMassSpectrumVectorMassDataIntegratorMetaTypeId;
 Q_DECLARE_METATYPE(
   msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorSPtr)
 extern int qualifiedMassSpectrumVectorMassDataIntegratorSPtrMetaTypeId;
-
