@@ -108,7 +108,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::
 void
 QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
 {
-  qDebug();
+  // qDebug();
 
   std::chrono::system_clock::time_point chrono_start_time =
     std::chrono::system_clock::now();
@@ -124,7 +124,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
       emit cancelOperationSignal();
     }
 
-  qDebug() << "The number of mass spectra to handle:" << mass_spectra_count;
+  // qDebug() << "The number of mass spectra to handle:" << mass_spectra_count;
 
   // We need to clear the map trace!
   m_mapTrace.clear();
@@ -156,17 +156,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
   // the ranges suffice, and they have been filled-in properly upon construction
   // of this integrator.
 
-  qDebug() << "Now filling-in the selection_polygon_specs for any 2D step that "
-              "has a source type involving the MZ data kind.";
+  // qDebug() << "Now filling-in the selection_polygon_specs for any 2D step that "
+  //             "has a source type involving the MZ data kind.";
 
-  std::vector<pappso::SelectionPolygonSpec> selection_polygon_specs;
+  std::vector<pappso::IntegrationScopeSpec> integration_scope_specs;
 
-  std::size_t selection_polygon_spec_count =
-    fillInSelectionPolygonSpecs(selection_polygon_specs);
-
-  qDebug() << selection_polygon_spec_count
-           << "selection polygon specs were retained for the configuration of "
-              "the filter.";
+  fillInIntegrationScopeSpecs(integration_scope_specs);
 
   // At this point, allocate a visitor that is specific for the calculation of
   // the mass spectrum. Since we are not binning, we can use a visitor that
@@ -210,7 +205,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
   // Now that we have all the parallel material, we can start the parallel work.
   emit setProgressBarMaxValueSignal(mass_spectra_count);
 
-  qDebug() << "Starting the iteration in the visitors.";
+  // qDebug() << "Starting the iteration in the visitors.";
 
   omp_set_num_threads(iterators.size());
 #pragma omp parallel for ordered
@@ -269,6 +264,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
               ++current_iterator;
               continue;
             }
+
           if(!checkMsFragmentation(qualified_mass_spectrum_csp))
             {
               qDebug() << "The MsFragmentation check returned false";
@@ -285,6 +281,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
               ++current_iterator;
               continue;
             }
+
           if(!checkDtRange(qualified_mass_spectrum_csp))
             {
               qDebug() << "checkDtRange failed check.";
@@ -293,46 +290,89 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
               continue;
             }
 
+          // qDebug() << "Passed the MSn, RT, DT checks.";
+
           double mass_spectrum_sum_y = 0;
 
           // Handle the mobility data, either drift time or 1/K0 depending
-          // on the file type. Do that now because we'll need the dt value when
-          // performing the sumY calculation if a filtering with selection in
-          // polygon is required.
+          // on the file type.
 
-          double dt = -1;
+          double ion_mobility_value = -1;
 
           // Get the format of the file, because that will condition the
           // way we provide mobility values.
 
-          pappso::MzFormat file_format =
+          pappso::MsDataFormat file_format =
             qualified_mass_spectrum_csp->getMassSpectrumId()
               .getMsRunIdCstSPtr()
-              ->getMzFormat();
+              ->getMsDataFormat();
 
-          if(file_format == pappso::MzFormat::brukerTims)
+          bool ok = false;
+
+          if(file_format == pappso::MsDataFormat::brukerTims)
             {
-              QVariant dt_variant_value =
+              // Start by looking if there is a OneOverK0 valid value, which
+              // means we have effectively handled a genuine mobility scan
+              // spectrum.
+              QVariant ion_mobility_variant_value =
                 qualified_mass_spectrum_csp->getParameterValue(
-                  pappso::QualifiedMassSpectrumParameter::OneOverK0);
+                  pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
 
-              if(!dt_variant_value.isValid())
+              if(ion_mobility_variant_value.isValid())
                 {
-                  qFatal(
-                    "The data are not Bruker timsTOF data. Inconsistency "
-                    "found.");
+                  // Yes, genuine ion mobility scan handled here.
+
+                  ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
+
+                  if(!ok)
+                    {
+                      qFatal(
+                        "The data are Bruker timsTOF data but failed to "
+                        "convert valid "
+                        "QVariant 1/K0 value to double.");
+                    }
                 }
-
-              bool ok = false;
-              dt      = dt_variant_value.toDouble(&ok);
-              if(!ok)
+              else
                 {
-                  qFatal("Failed to convert QVariant 1/K0 value to double.");
+                  // We are not handling a genuine single ion mobility scan
+                  // here. We must be handling a mass spectrum that correspond
+                  // to the combination of all the ion mobility scans for a
+                  // single frame. This is when the user asks that ion mobility
+                  // scans be flattended. In this case, the OneOverK0 value is
+                  // not valid but there are two values that are set:
+                  // TimsFrameInvKoBegin and TimsFrameInvKoEnd.
+                  // See TimsFramesMsRunReader::readSpectrumCollection2.
+
+                  // Test one of these values as a sanity check. But
+                  // give the value of -1 for the ion mobility because we do not
+                  // have ion mobility data here.
+
+                  ion_mobility_variant_value =
+                    qualified_mass_spectrum_csp->getParameterValue(
+                      pappso::QualifiedMassSpectrumParameter::
+                        TimsFrameIonMobOneOverK0Begin);
+
+                  if(!ion_mobility_variant_value.isValid())
+                    {
+                      qFatal(
+                        "The data are Bruker timsTOF data but failed to get "
+                        "correct "
+                        "ion mobility data. Inconsistency found.");
+                    }
                 }
             }
           else
             {
-              dt = qualified_mass_spectrum_csp->getDtInMilliSeconds();
+              ion_mobility_value =
+                qualified_mass_spectrum_csp->getDtInMilliSeconds();
+            }
+
+          if(ion_mobility_value == -1)
+            {
+              // qDebug() << "Not ion mobility data.";
+
+              ++current_iterator;
+              continue;
             }
 
           // At this point we need to account for any limitations in the m/z
@@ -341,8 +381,13 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
           // steps involving the m/z dimension in the m_innermostSteps2D, if the
           // selection polygons are not rectangle.
 
-          if(!selection_polygon_specs.size())
+          if(!integration_scope_specs.size())
             {
+              // qDebug() << "There were no integration_scope_specs.";
+
+              // qDebug() << "m_mzRange.first:" << m_mzRange.first
+              //          << "m_mzRange.second:" << m_mzRange.second;
+
               if(!std::isnan(m_mzRange.first) && !std::isnan(m_mzRange.second))
                 {
                   mass_spectrum_sum_y =
@@ -358,17 +403,20 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
           else
             {
               // It may be possible that the 2D steps limiting the m/z range
-              // have been followed by 1D steps further limiting the m/Z range.
+              // have been followed by 1D steps further limiting the m/z range.
               // The point is, the 1D steps are not stored in
               // selection_polygon_specs. However, by necessity, if there is at
               // least one selection_polygon_spec, then the m_mzRange holds
-              // values. Futher, if there had been a 1D step limiting even more
+              // values. Further, if there had been a 1D step limiting even more
               // the m/z range, then that step would have been accounted for in
               // m_mzRange. So we can account that limit right away.
 
               if(std::isnan(m_mzRange.first) || std::isnan(m_mzRange.second))
                 qFatal("Programming error.");
 
+              // qDebug() << "m_mzRange.first:" << m_mzRange.first
+              //          << "m_mzRange.second:" << m_mzRange.second;
+
               pappso::Trace filtered_trace(
                 *qualified_mass_spectrum_csp->getMassSpectrumSPtr());
 
@@ -378,11 +426,11 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
               filtered_trace = the_keep_filter.filter(filtered_trace);
 
               pappso::FilterResampleKeepPointInPolygon the_polygon_filter(
-                selection_polygon_specs);
+                integration_scope_specs);
 
               filtered_trace = the_polygon_filter.filter(
                 filtered_trace,
-                dt,
+                ion_mobility_value,
                 qualified_mass_spectrum_csp->getRtInMinutes());
 
               mass_spectrum_sum_y = filtered_trace.sumY();
@@ -397,7 +445,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
           // Try to insert the pair into the map. Check if that was done or
           // not.
           std::pair<DtTicMapIterator, bool> res =
-            current_dt_spec_map_sp->insert(Pair(dt, mass_spectrum_sum_y));
+            current_dt_spec_map_sp->insert(
+              Pair(ion_mobility_value, mass_spectrum_sum_y));
 
           if(!res.second)
             {
@@ -463,11 +512,11 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
 
           emit setProgressBarCurrentValueSignal(iter);
 
-          double rt  = pair.first;
-          double tic = pair.second;
+          double ion_mobility_value = pair.first;
+          double tic                = pair.second;
 
           std::pair<DtTicMapIterator, bool> res =
-            m_mapTrace.insert(Pair(rt, tic));
+            m_mapTrace.insert(Pair(ion_mobility_value, tic));
 
           if(!res.second)
             {
