@@ -304,16 +304,9 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
   // the ranges suffice, and they have been filled-in properly upon construction
   // of this integrator.
 
-  // qDebug() << "Now filling-in the selectionpolygonspecs.";
+  std::vector<pappso::IntegrationScopeSpec> integration_scope_specs;
 
-  std::vector<pappso::SelectionPolygonSpec> selection_polygon_specs;
-
-  // std::size_t selection_polygon_spec_count =
-  fillInSelectionPolygonSpecs(selection_polygon_specs);
-
-  // qDebug() << selection_polygon_spec_count
-  //<< "selection polygon specs were retained for the configuration of "
-  //"the filter.";
+  fillInIntegrationScopeSpecs(integration_scope_specs);
 
   // Prepare the template for all the combiners we'll use in the different
   // threads.
@@ -479,7 +472,87 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
           // to get the dt|rt value for it.
 
           double rt_value = qualified_mass_spectrum_csp->getRtInMinutes();
-          double dt_value = qualified_mass_spectrum_csp->getDtInMilliSeconds();
+
+          // Handle the mobility data, either drift time or 1/K0 depending
+          // on the file type.
+
+          double ion_mobility_value = -1;
+
+          // Get the format of the file, because that will condition the
+          // way we provide mobility values.
+
+          pappso::MsDataFormat file_format =
+            qualified_mass_spectrum_csp->getMassSpectrumId()
+              .getMsRunIdCstSPtr()
+              ->getMsDataFormat();
+
+          bool ok = false;
+
+          if(file_format == pappso::MsDataFormat::brukerTims)
+            {
+              // Start by looking if there is a OneOverK0 valid value, which
+              // means we have effectively handled a genuine mobility scan
+              // spectrum.
+              QVariant ion_mobility_variant_value =
+                qualified_mass_spectrum_csp->getParameterValue(
+                  pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+
+              if(ion_mobility_variant_value.isValid())
+                {
+                  // Yes, genuine ion mobility scan handled here.
+
+                  ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
+
+                  if(!ok)
+                    {
+                      qFatal(
+                        "The data are Bruker timsTOF data but failed to "
+                        "convert valid "
+                        "QVariant 1/K0 value to double.");
+                    }
+                }
+              else
+                {
+                  // We are not handling a genuine single ion mobility scan
+                  // here. We must be handling a mass spectrum that correspond
+                  // to the combination of all the ion mobility scans for a
+                  // single frame. This is when the user asks that ion mobility
+                  // scans be flattended. In this case, the OneOverK0 value is
+                  // not valid but there are two values that are set:
+                  // TimsFrameInvKoBegin and TimsFrameInvKoEnd.
+                  // See TimsFramesMsRunReader::readSpectrumCollection2.
+
+                  // Test one of these values as a sanity check. But
+                  // give the value of -1 for the ion mobility because we do not
+                  // have ion mobility data here.
+
+                  ion_mobility_variant_value =
+                    qualified_mass_spectrum_csp->getParameterValue(
+                      pappso::QualifiedMassSpectrumParameter::
+                        TimsFrameIonMobOneOverK0Begin);
+
+                  if(!ion_mobility_variant_value.isValid())
+                    {
+                      qFatal(
+                        "The data are Bruker timsTOF data but failed to get "
+                        "correct "
+                        "ion mobility data. Inconsistency found.");
+                    }
+                }
+            }
+          else
+            {
+              ion_mobility_value =
+                qualified_mass_spectrum_csp->getDtInMilliSeconds();
+            }
+
+          if(ion_mobility_value == -1)
+            {
+              qDebug() << "Not ion mobility data.";
+
+              ++current_iterator;
+              continue;
+            }
 
           double first_key; // that is, either rt or dt.
 
@@ -489,7 +562,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
             }
           else if(m_lastIntegrationDataKind == pappso::DataKind::dt)
             {
-              first_key = dt_value;
+              first_key = ion_mobility_value;
             }
           else
             qFatal("Programming error.");
@@ -525,15 +598,13 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
               filtered_trace = the_keep_filter.filter(filtered_trace);
             }
 
-          if(selection_polygon_specs.size())
+          if(integration_scope_specs.size())
             {
               pappso::FilterResampleKeepPointInPolygon the_polygon_filter(
-                selection_polygon_specs);
+                integration_scope_specs);
 
               filtered_trace = the_polygon_filter.filter(
-                filtered_trace,
-                qualified_mass_spectrum_csp->getDtInMilliSeconds(),
-                qualified_mass_spectrum_csp->getRtInMinutes());
+                filtered_trace, ion_mobility_value, rt_value);
             }
 
           // At this point we can make the combination with the filtered trace.
@@ -782,15 +853,9 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   // spectrum combination.
   // QString debug_string = "";
 
-  // qDebug() << "Now filling-in the selectionpolygonspecs.";
+  std::vector<pappso::IntegrationScopeSpec> integration_scope_specs;
 
-  std::vector<pappso::SelectionPolygonSpec> selection_polygon_specs;
-
-  // std::size_t selection_polygon_spec_count =
-  fillInSelectionPolygonSpecs(selection_polygon_specs);
-  // qDebug() << selection_polygon_spec_count
-  //<< "selection polygon specs were retained for the configuration of "
-  //"the filter.";
+  fillInIntegrationScopeSpecs(integration_scope_specs);
 
   // Prepare the template for all the combiners we'll use in the different
   // threads.
@@ -1009,7 +1074,45 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
           // to get the dt|rt value for it.
 
           double rt_value = qualified_mass_spectrum_csp->getRtInMinutes();
-          double dt_value = qualified_mass_spectrum_csp->getDtInMilliSeconds();
+
+          // Handle the mobility data, either drift time or 1/K0 depending
+          // on the file type.
+
+          double ion_mobility_value = -1;
+
+          // Get the format of the file, because that will condition the
+          // way we provide mobility values.
+
+          pappso::MsDataFormat file_format =
+            qualified_mass_spectrum_csp->getMassSpectrumId()
+              .getMsRunIdCstSPtr()
+              ->getMsDataFormat();
+
+          if(file_format == pappso::MsDataFormat::brukerTims)
+            {
+              QVariant ion_mobility_variant_value =
+                qualified_mass_spectrum_csp->getParameterValue(
+                  pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+
+              if(!ion_mobility_variant_value.isValid())
+                {
+                  qFatal(
+                    "The data are not Bruker timsTOF data. Inconsistency "
+                    "found.");
+                }
+
+              bool ok            = false;
+              ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
+              if(!ok)
+                {
+                  qFatal("Failed to convert QVariant 1/K0 value to double.");
+                }
+            }
+          else
+            {
+              ion_mobility_value =
+                qualified_mass_spectrum_csp->getDtInMilliSeconds();
+            }
 
           double first_key; // that is, either rt or dt.
 
@@ -1021,7 +1124,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
             }
           else if(m_lastIntegrationDataKind == pappso::DataKind::dt)
             {
-              first_key = dt_value;
+              first_key = ion_mobility_value;
               // qDebug() << "The dt|rt key is actually a DT key with value:"
               //<< first_key;
             }
@@ -1053,18 +1156,16 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
               filtered_trace = the_keep_filter.filter(filtered_trace);
             }
 
-          if(selection_polygon_specs.size())
+          if(integration_scope_specs.size())
             {
               // qDebug() << "There appears to be an selection polygon-based "
               //"filtering need.";
 
               pappso::FilterResampleKeepPointInPolygon the_polygon_filter(
-                selection_polygon_specs);
+                integration_scope_specs);
 
               filtered_trace = the_polygon_filter.filter(
-                filtered_trace,
-                qualified_mass_spectrum_csp->getDtInMilliSeconds(),
-                qualified_mass_spectrum_csp->getRtInMinutes());
+                filtered_trace, ion_mobility_value, rt_value);
             }
 
           // At this point we can make the combination with the filtered trace.
