@@ -194,16 +194,9 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
   // at combination time, because that is precisely the only moment that we can
   // do that work.
 
-  // qDebug() << "Now filling-in the selectionpolygonspecs.";
+  std::vector<pappso::IntegrationScopeSpec> integration_scope_specs;
 
-  std::vector<pappso::SelectionPolygonSpec> selection_polygon_specs;
-
-  // std::size_t selection_polygon_spec_count =
-  fillInSelectionPolygonSpecs(selection_polygon_specs);
-
-  // qDebug() << selection_polygon_spec_count
-  //<< "selection polygon specs were retained for the configuration of "
-  //"the filter.";
+  fillInIntegrationScopeSpecs(integration_scope_specs);
 
   // Prepare the template for all the combiners we'll use in the different
   // threads.
@@ -400,14 +393,49 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
               filtered_trace = the_keep_filter.filter(filtered_trace);
             }
 
-          if(selection_polygon_specs.size())
+          // Handle the mobility data, either drift time or 1/K0 depending
+          // on the file type.
+          double ion_mobility_value = -1;
+
+          // Get the format of the file, because that will condition the
+          // way we provide mobility values.
+
+          pappso::MsDataFormat file_format =
+            qualified_mass_spectrum_csp->getMassSpectrumId()
+              .getMsRunIdCstSPtr()
+              ->getMsDataFormat();
+
+          if(file_format == pappso::MsDataFormat::brukerTims)
+            {
+              QVariant ion_mobility_variant_value =
+                qualified_mass_spectrum_csp->getParameterValue(
+                  pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+
+              if(ion_mobility_variant_value.isValid())
+                {
+                  bool ok            = false;
+                  ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
+                  if(!ok)
+                    {
+                      qFatal(
+                        "Failed to convert QVariant 1/K0 value to double.");
+                    }
+                }
+            }
+          else
+            {
+              ion_mobility_value =
+                qualified_mass_spectrum_csp->getDtInMilliSeconds();
+            }
+
+          if(integration_scope_specs.size())
             {
               pappso::FilterResampleKeepPointInPolygon the_polygon_filter(
-                selection_polygon_specs);
+                integration_scope_specs);
 
               filtered_trace = the_polygon_filter.filter(
                 filtered_trace,
-                qualified_mass_spectrum_csp->getDtInMilliSeconds(),
+                ion_mobility_value,
                 qualified_mass_spectrum_csp->getRtInMinutes());
             }
 
@@ -607,16 +635,9 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   // at combination time, because that is precisely the only moment that we can
   // do that work.
 
-  // qDebug() << "Now filling-in the selectionpolygonspecs.";
+  std::vector<pappso::IntegrationScopeSpec> integration_scope_specs;
 
-  std::vector<pappso::SelectionPolygonSpec> selection_polygon_specs;
-
-  // std::size_t selection_polygon_spec_count =
-  fillInSelectionPolygonSpecs(selection_polygon_specs);
-
-  // qDebug() << selection_polygon_spec_count
-  //<< "selection polygon specs were retained for the configuration of "
-  //"the filter.";
+  fillInIntegrationScopeSpecs(integration_scope_specs);
 
   // Prepare the template for all the combiners we'll use in the different
   // threads.
@@ -794,10 +815,10 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
               filtered_trace = the_keep_filter.filter(filtered_trace);
             }
 
-          if(selection_polygon_specs.size())
+          if(integration_scope_specs.size())
             {
               pappso::FilterResampleKeepPointInPolygon the_polygon_filter(
-                selection_polygon_specs);
+                integration_scope_specs);
 
               if(!filtered_trace.size())
                 {
@@ -805,9 +826,46 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
                     *qualified_mass_spectrum_csp->getMassSpectrumSPtr());
                 }
 
+
+              // Handle the mobility data, either drift time or 1/K0 depending
+              // on the file type.
+              double ion_mobility_value = -1;
+
+              // Get the format of the file, because that will condition the
+              // way we provide mobility values.
+
+              pappso::MsDataFormat file_format =
+                qualified_mass_spectrum_csp->getMassSpectrumId()
+                  .getMsRunIdCstSPtr()
+                  ->getMsDataFormat();
+
+              if(file_format == pappso::MsDataFormat::brukerTims)
+                {
+                  QVariant ion_mobility_variant_value =
+                    qualified_mass_spectrum_csp->getParameterValue(
+                      pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+
+                  if(ion_mobility_variant_value.isValid())
+                    {
+                      bool ok = false;
+                      ion_mobility_value =
+                        ion_mobility_variant_value.toDouble(&ok);
+                      if(!ok)
+                        {
+                          qFatal(
+                            "Failed to convert QVariant 1/K0 value to double.");
+                        }
+                    }
+                }
+              else
+                {
+                  ion_mobility_value =
+                    qualified_mass_spectrum_csp->getDtInMilliSeconds();
+                }
+
               filtered_trace = the_polygon_filter.filter(
                 filtered_trace,
-                qualified_mass_spectrum_csp->getDtInMilliSeconds(),
+                ion_mobility_value,
                 qualified_mass_spectrum_csp->getRtInMinutes());
             }
 
