@@ -221,16 +221,9 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
   // the ranges suffice, and they have been filled-in properly upon construction
   // of this integrator.
 
-  qDebug() << "Now filling-in the selection_polygon_specs.";
+  std::vector<pappso::IntegrationScopeSpec> integration_scope_specs;
 
-  std::vector<pappso::SelectionPolygonSpec> selection_polygon_specs;
-
-  std::size_t selection_polygon_spec_count =
-    fillInSelectionPolygonSpecs(selection_polygon_specs);
-
-  qDebug() << selection_polygon_spec_count
-           << "selection polygon specs were retained for the configuration of "
-              "the filter.";
+  fillInIntegrationScopeSpecs(integration_scope_specs);
 
   // Using a shared pointer make it easy to handle the copying of the map to
   // users of that map without bothering.
@@ -377,9 +370,89 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
               continue;
             }
 
-          double dt_key = qualified_mass_spectrum_csp->getDtInMilliSeconds();
           double rt_key = qualified_mass_spectrum_csp->getRtInMinutes();
 
+          // Handle the mobility data, either drift time or 1/K0 depending
+          // on the file type.
+
+          double ion_mobility_value = -1;
+
+          // Get the format of the file, because that will condition the
+          // way we provide mobility values.
+
+          pappso::MsDataFormat file_format =
+            qualified_mass_spectrum_csp->getMassSpectrumId()
+              .getMsRunIdCstSPtr()
+              ->getMsDataFormat();
+
+          bool ok = false;
+
+          if(file_format == pappso::MsDataFormat::brukerTims)
+            {
+              // Start by looking if there is a OneOverK0 valid value, which
+              // means we have effectively handled a genuine mobility scan
+              // spectrum.
+              QVariant ion_mobility_variant_value =
+                qualified_mass_spectrum_csp->getParameterValue(
+                  pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+
+              if(ion_mobility_variant_value.isValid())
+                {
+                  // Yes, genuine ion mobility scan handled here.
+
+                  ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
+
+                  if(!ok)
+                    {
+                      qFatal(
+                        "The data are Bruker timsTOF data but failed to "
+                        "convert valid "
+                        "QVariant 1/K0 value to double.");
+                    }
+                }
+              else
+                {
+                  // We are not handling a genuine single ion mobility scan
+                  // here. We must be handling a mass spectrum that correspond
+                  // to the combination of all the ion mobility scans for a
+                  // single frame. This is when the user asks that ion mobility
+                  // scans be flattended. In this case, the OneOverK0 value is
+                  // not valid but there are two values that are set:
+                  // TimsFrameInvKoBegin and TimsFrameInvKoEnd.
+                  // See TimsFramesMsRunReader::readSpectrumCollection2.
+
+                  // Test one of these values as a sanity check. But
+                  // give the value of -1 for the ion mobility because we do not
+                  // have ion mobility data here.
+
+                  ion_mobility_variant_value =
+                    qualified_mass_spectrum_csp->getParameterValue(
+                      pappso::QualifiedMassSpectrumParameter::
+                        TimsFrameIonMobOneOverK0Begin);
+
+                  if(!ion_mobility_variant_value.isValid())
+                    {
+                      qFatal(
+                        "The data are Bruker timsTOF data but failed to get "
+                        "correct "
+                        "ion mobility data. Inconsistency found.");
+                    }
+                }
+            }
+          else
+            {
+              ion_mobility_value =
+                qualified_mass_spectrum_csp->getDtInMilliSeconds();
+            }
+
+          if(ion_mobility_value == -1)
+            {
+              qDebug() << "Not ion mobility data.";
+
+              ++current_iterator;
+              continue;
+            }
+
           double mass_spectrum_sum_y = 0;
 
           // We want to know what is the TIC intensity value of the spectrum.
@@ -390,7 +463,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
           // steps involving the m/z dimension in the m_innermostSteps2D, if the
           // selection polygons are not rectangle.
 
-          if(!selection_polygon_specs.size())
+          if(!integration_scope_specs.size())
             {
               if(!std::isnan(m_mzRange.first) && !std::isnan(m_mzRange.second))
                 {
@@ -427,10 +500,10 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
               filtered_trace = the_keep_filter.filter(filtered_trace);
 
               pappso::FilterResampleKeepPointInPolygon the_polygon_filter(
-                selection_polygon_specs);
+                integration_scope_specs);
 
-              filtered_trace =
-                the_polygon_filter.filter(filtered_trace, dt_key, rt_key);
+              filtered_trace = the_polygon_filter.filter(
+                filtered_trace, ion_mobility_value, rt_key);
 
               mass_spectrum_sum_y = filtered_trace.sumY();
             }
@@ -456,19 +529,21 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
 
               // The map already contained a pair that had the key value ==
               // rt_key (->first membero of the pair). The ->second member of
-              // the pair is the MapTrace that maps <dt_key, TICint>. So we
-              // now need to search for a map item that has key == dt_key.
+              // the pair is the MapTrace that maps <ion_mobility_value_key,
+              // TICint>. So we now need to search for a map item that has key
+              // == ion_mobility_value_key.
 
               using MapIterator = std::map<double, double>::iterator;
 
               std::pair<MapIterator, bool> res =
                 double_maptrace_map_iterator->second.insert(
-                  std::pair<double, double>(dt_key, mass_spectrum_sum_y));
+                  std::pair<double, double>(ion_mobility_value,
+                                            mass_spectrum_sum_y));
 
               if(!res.second)
                 {
-                  // One other same dt_key value was seen already. Only
-                  // increment the y value.
+                  // One other same ion_mobility_value_key value was seen
+                  // already. Only increment the y value.
 
                   res.first->second += mass_spectrum_sum_y;
                 }
@@ -476,21 +551,22 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
           else
             {
 
-              // This is the first time that we encounter dt_key. So we need
-              // to create a new MapTrace for that dt_key. That MapTrace
+              // This is the first time that we encounter
+              // ion_mobility_value_key. So we need to create a new MapTrace for
+              // that ion_mobility_value_key. That MapTrace
               // (std::map<double,double>) will store the TIC values for all the
-              // dt_key elements.
+              // ion_mobility_value_key elements.
 
               // Instantiate a new MapTrace in which we'll store all the TIC
-              // intensities for all the dt_key map items.
+              // intensities for all the ion_mobility_value_key map items.
 
               pappso::MapTrace map_trace;
 
-              map_trace.insert(
-                std::pair<double, double>(dt_key, mass_spectrum_sum_y));
+              map_trace.insert(std::pair<double, double>(ion_mobility_value,
+                                                         mass_spectrum_sum_y));
 
               // Finally, store in the map<double, MapTrace> map, the map_trace
-              // along with its dt_key.
+              // along with its ion_mobility_value_key.
 
               (*iterated_rt_maptrace_map_sp)[rt_key] = map_trace;
             }
@@ -540,7 +616,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
 
       for(auto &&pair : *map_sp)
         {
-          // first is the dt_key
+          // first is the ion_mobility_value_key
           // second is the pappso::MapTrace
 
           emit setStatusTextSignal(
@@ -548,35 +624,39 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
 
           emit setProgressBarCurrentValueSignal(iter);
 
-          double dt_key = pair.first;
+          double ion_mobility_value_key = pair.first;
 
           pappso::MapTrace current_maptrace = pair.second;
 
-          // Now search in the member if a dt_key was found already.
+          // Now search in the member if a ion_mobility_value_key was found
+          // already.
 
           Map::iterator double_maptrace_map_iterator;
 
-          double_maptrace_map_iterator = m_rtMapTraceMapSPtr->find(dt_key);
+          double_maptrace_map_iterator =
+            m_rtMapTraceMapSPtr->find(ion_mobility_value_key);
 
           // Tells if the key was already found in the map.
           if(double_maptrace_map_iterator != m_rtMapTraceMapSPtr->end())
             {
-              // qDebug() << "Adding new key value:" << rt_or_dt_key;
+              // qDebug() << "Adding new key value:" <<
+              // rt_or_ion_mobility_value_key;
 
               // The map already contained a pair that had the key value ==
-              // dt_key. We want to sum, map item by map item all the map
-              // items in the current_maptrace MapTrace to
-              // the combined one that will hold the final color map data:
+              // ion_mobility_value_key. We want to sum, map item by map item
+              // all the map items in the current_maptrace MapTrace to the
+              // combined one that will hold the final color map data:
               // double_maptrace_map_iterator->second.
 
               // For example, thread 1 yielded a <double, MapTrace> map like
-              // this: <rt, map<dt, tic>>. rt is dt_key and dt is rt_key.
+              // this: <rt, map<dt, tic>>. rt is ion_mobility_value_key and dt
+              // is rt_key.
 
               // We search in the member <double, MapTrace> map if an item has a
-              // value matching rt (that is, dt_key). If found then we need
-              // to combine the iterated MapTrace into the member MapTrace for
-              // key dt_key. It's like if MapTrace were a mass spectrum, but
-              // in fact m/z is replaced with dt.
+              // value matching rt (that is, ion_mobility_value_key). If found
+              // then we need to combine the iterated MapTrace into the member
+              // MapTrace for key ion_mobility_value_key. It's like if MapTrace
+              // were a mass spectrum, but in fact m/z is replaced with dt.
 
               // qDebug() << "Before combination, map trace map size: "
               //<< double_map_trace_map_iterator->second.size();
@@ -588,16 +668,17 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
             {
 
               // No map<double, MapTrace> item was found with double equals to
-              // dt_key. So we need to create a MapTrace ex nihilo.
+              // ion_mobility_value_key. So we need to create a MapTrace ex
+              // nihilo.
 
               pappso::MapTrace map_trace;
 
               combiner.combine(map_trace, current_maptrace);
 
               // Finally, store in the map, the map_trace along with its
-              // dt_key.
+              // ion_mobility_value_key.
 
-              (*m_rtMapTraceMapSPtr)[dt_key] = map_trace;
+              (*m_rtMapTraceMapSPtr)[ion_mobility_value_key] = map_trace;
             }
         }
     }
