@@ -177,17 +177,9 @@ QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::integrate()
   // the ranges suffice, and they have been filled-in properly upon construction
   // of this integrator.
 
-  qDebug() << "Now filling-in the selection_polygon_specs for any 2D step that "
-              "has a source type involving the MZ data kind.";
+  std::vector<pappso::IntegrationScopeSpec> integration_scope_specs;
 
-  std::vector<pappso::SelectionPolygonSpec> selection_polygon_specs;
-
-  std::size_t selection_polygon_spec_count =
-    fillInSelectionPolygonSpecs(selection_polygon_specs);
-
-  qDebug() << selection_polygon_spec_count
-           << "selection polygon specs were retained for the configuration of "
-              "the filter.";
+  fillInIntegrationScopeSpecs(integration_scope_specs);
 
   // Determine the best number of threads to use and how many spectra to provide
   // each of the threads.
@@ -315,7 +307,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::integrate()
           // steps involving the m/z dimension in the m_innermostSteps2D, if the
           // selection polygons are not rectangle.
 
-          if(!selection_polygon_specs.size())
+          if(!integration_scope_specs.size())
             {
               if(!std::isnan(m_mzRange.first) && !std::isnan(m_mzRange.second))
                 {
@@ -352,11 +344,47 @@ QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::integrate()
               filtered_trace = the_keep_filter.filter(filtered_trace);
 
               pappso::FilterResampleKeepPointInPolygon the_polygon_filter(
-                selection_polygon_specs);
+                integration_scope_specs);
+
+              // Handle the mobility data, either drift time or 1/K0 depending
+              // on the file type.
+              double ion_mobility_value = -1;
+
+              // Get the format of the file, because that will condition the
+              // way we provide mobility values.
+
+              pappso::MsDataFormat file_format =
+                qualified_mass_spectrum_csp->getMassSpectrumId()
+                  .getMsRunIdCstSPtr()
+                  ->getMsDataFormat();
+
+              if(file_format == pappso::MsDataFormat::brukerTims)
+                {
+                  QVariant ion_mobility_variant_value =
+                    qualified_mass_spectrum_csp->getParameterValue(
+                      pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+
+                  if(ion_mobility_variant_value.isValid())
+                    {
+                      bool ok = false;
+                      ion_mobility_value =
+                        ion_mobility_variant_value.toDouble(&ok);
+                      if(!ok)
+                        {
+                          qFatal(
+                            "Failed to convert QVariant 1/K0 value to double.");
+                        }
+                    }
+                }
+              else
+                {
+                  ion_mobility_value =
+                    qualified_mass_spectrum_csp->getDtInMilliSeconds();
+                }
 
               filtered_trace = the_polygon_filter.filter(
                 filtered_trace,
-                qualified_mass_spectrum_csp->getDtInMilliSeconds(),
+                ion_mobility_value,
                 qualified_mass_spectrum_csp->getRtInMinutes());
 
               *current_tic_intensity_sp += filtered_trace.sumY();
