@@ -69,10 +69,9 @@ class RtDtColorMapTreeNodeCombinerVisitor
 {
 
   public:
-  RtDtColorMapTreeNodeCombinerVisitor(
-    MsRunDataSetCstSPtr ms_run_data_set_csp,
-    const ProcessingFlow &processing_flow,
-    pappso::DataKind data_kind);
+  RtDtColorMapTreeNodeCombinerVisitor(MsRunDataSetCstSPtr ms_run_data_set_csp,
+                                      const ProcessingFlow &processing_flow,
+                                      pappso::DataKind data_kind);
 
   RtDtColorMapTreeNodeCombinerVisitor(
     const RtDtColorMapTreeNodeCombinerVisitor &other);
